% Auto-generated chapter 21 for abudawud
% Hadiths in this chapter: 153

\hadithdefcmd{abudawud}{3089}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي رَجُلٌ، مِنْ أَهْلِ الشَّامِ يُقَالُ لَهُ أَبُو مَنْظُورٍ عَنْ عَمِّهِ، قَالَ حَدَّثَنِي عَمِّي، عَنْ عَامِرٍ الرَّامِ، أَخِي الْخُضْرِ - قَالَ أَبُو دَاوُدَ قَالَ النُّفَيْلِيُّ هُوَ الْخُضْرُ وَلَكِنْ كَذَا قَالَ - قَالَ إِنِّي لَبِبِلاَدِنَا إِذْ رُفِعَتْ لَنَا رَايَاتٌ وَأَلْوِيَةٌ فَقُلْتُ مَا هَذَا قَالُوا هَذَا لِوَاءُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ وَهُوَ تَحْتَ شَجَرَةٍ قَدْ بُسِطَ لَهُ كِسَاءٌ وَهُوَ جَالِسٌ عَلَيْهِ وَقَدِ اجْتَمَعَ إِلَيْهِ أَصْحَابُهُ فَجَلَسْتُ إِلَيْهِمْ فَذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الأَسْقَامَ فَقَالَ ‏"‏ إِنَّ الْمُؤْمِنَ إِذَا أَصَابَهُ السَّقَمُ ثُمَّ أَعْفَاهُ اللَّهُ مِنْهُ كَانَ كَفَّارَةً لِمَا مَضَى مِنْ ذُنُوبِهِ وَمَوْعِظَةً لَهُ فِيمَا يَسْتَقْبِلُ وَإِنَّ الْمُنَافِقَ إِذَا مَرِضَ ثُمَّ أُعْفِيَ كَانَ كَالْبَعِيرِ عَقَلَهُ أَهْلُهُ ثُمَّ أَرْسَلُوهُ فَلَمْ يَدْرِ لِمَ عَقَلُوهُ وَلَمْ يَدْرِ لِمَ أَرْسَلُوهُ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِمَّنْ حَوْلَهُ يَا رَسُولَ اللَّهِ وَمَا الأَسْقَامُ وَاللَّهِ مَا مَرِضْتُ قَطُّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُمْ عَنَّا فَلَسْتَ مِنَّا ‏"‏ ‏.‏ فَبَيْنَا نَحْنُ عِنْدَهُ إِذْ أَقْبَلَ رَجُلٌ عَلَيْهِ كِسَاءٌ وَفِي يَدِهِ شَىْءٌ قَدِ الْتَفَّ عَلَيْهِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لَمَّا رَأَيْتُكَ أَقْبَلْتُ إِلَيْكَ فَمَرَرْتُ بِغَيْضَةِ شَجَرٍ فَسَمِعْتُ فِيهَا أَصْوَاتَ فِرَاخِ طَائِرٍ فَأَخَذْتُهُنَّ فَوَضَعْتُهُنَّ فِي كِسَائِي فَجَاءَتْ أُمُّهُنَّ فَاسْتَدَارَتْ عَلَى رَأْسِي فَكَشَفْتُ لَهَا عَنْهُنَّ فَوَقَعَتْ عَلَيْهِنَّ مَعَهُنَّ فَلَفَفْتُهُنَّ بِكِسَائِي فَهُنَّ أُولاَءِ مَعِي ‏.‏ قَالَ ‏"‏ ضَعْهُنَّ عَنْكَ ‏"‏ ‏.‏ فَوَضَعْتُهُنَّ وَأَبَتْ أُمُّهُنَّ إِلاَّ لُزُومَهُنَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ أَتَعْجَبُونَ لِرُحْمِ أُمِّ الأَفْرَاخِ فِرَاخَهَا ‏"‏ ‏.‏ قَالُوا نَعَمْ يَا رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ فَوَالَّذِي بَعَثَنِي بِالْحَقِّ لَلَّهُ أَرْحَمُ بِعِبَادِهِ مِنْ أُمِّ الأَفْرَاخِ بِفِرَاخِهَا ارْجِعْ بِهِنَّ حَتَّى تَضَعَهُنَّ مِنْ حَيْثُ أَخَذْتَهُنَّ وَأُمُّهُنَّ مَعَهُنَّ ‏"‏ ‏.‏ فَرَجَعَ بِهِنَّ ‏.‏\hadithno{3089}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amir ar-Ram: We were in our country when flags and banners were raised. I said: What is this? The (the people) said: This is the banner of the Messenger of Allah (ﷺ). So I came to him. He was (sitting) under a tree. A sheet of cloth was spread for him and he was sitting on it. His Companions were gathered around him. I sat with them. The Messenger of Allah (ﷺ) mentioned illness and said: When a believer is afflicted by illness and Allah cures him of it, it serves as an atonement for his previous sins and a warning to him for the future. But when a hypocrite becomes ill and is then cured, he is like a camel which has been tethered and then let loose by its owners, but does not know why they tethered it and why they let it loose. A man from among those around him asked: Messenger of Allah, what are illnesses? I swear by Allah, I never fell ill. The Messenger of Allah (ﷺ) said: Get up and leave us. You do not belong to our number. When we were with him, a man came to him. He had a sheet of cloth and something in his hand. He turned his attention to him and said: Messenger of Allah, when I saw you, I turned towards you. I saw a group of trees and heard the sound of fledglings. I took them and put them in my garment. Their mother then came and began to hover round my head. I showed them to her, and she fell on them. I wrapped them with my garment. They are now with me. He said: Put them away from you. So I put them away, but their mother stayed with them. The Messenger of Allah (ﷺ) said to his companions: Are you surprised at the affection of the mother for her young? They said: Yes, Messenger of Allah. He said: I swear by Him Who has sent me with the Truth, Allah is more affectionate to His servants than a mother to her young ones. Take them back put them and where you took them from when their mother should have been with them. So he took them back}}
\hadithdefcmd{abudawud}{3090}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، وَإِبْرَاهِيمُ بْنُ مَهْدِيٍّ الْمِصِّيصِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو الْمَلِيحِ، عَنْ مُحَمَّدِ بْنِ خَالِدٍ، - قَالَ أَبُو دَاوُدَ قَالَ إِبْرَاهِيمُ بْنُ مَهْدِيٍّ السُّلَمِيُّ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، وَكَانَتْ، لَهُ صُحْبَةٌ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْعَبْدَ إِذَا سَبَقَتْ لَهُ مِنَ اللَّهِ مَنْزِلَةٌ لَمْ يَبْلُغْهَا بِعَمَلِهِ ابْتَلاَهُ اللَّهُ فِي جَسَدِهِ أَوْ فِي مَالِهِ أَوْ فِي وَلَدِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ ابْنُ نُفَيْلٍ ‏"‏ ثُمَّ صَبَّرَهُ عَلَى ذَلِكَ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا ‏"‏ حَتَّى يُبْلِغَهُ الْمَنْزِلَةَ الَّتِي سَبَقَتْ لَهُ مِنَ اللَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{3090}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Muhammad ibn Khalid as-Sulami: on his father's authority said his grandfather reported: He was a Companion of the Messenger of Allah (ﷺ) said: I heard the Messenger of Allah (ﷺ) say: When Allah has previously decreed for a servant a rank which he has not attained by his action, He afflicts him in his body, or his property or his children. Abu Dawud said: Ibn Nufail added in his version: "He then enables him to endure that." The agreed version goes: "So that He may bring him to the rank previously decreed from him by Allah}}
\hadithdefcmd{abudawud}{3091}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا هُشَيْمٌ، عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ السَّكْسَكِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم غَيْرَ مَرَّةٍ وَلاَ مَرَّتَيْنِ يَقُولُ ‏ "‏ إِذَا كَانَ الْعَبْدُ يَعْمَلُ عَمَلاً صَالِحًا فَشَغَلَهُ عَنْهُ مَرَضٌ أَوْ سَفَرٌ كُتِبَ لَهُ كَصَالِحِ مَا كَانَ يَعْمَلُ وَهُوَ صَحِيحٌ مُقِيمٌ ‏"‏ ‏.‏\hadithno{3091}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih Bukhari (2996)}\hadithtrans{Narrated Abu Musa:I heard the Prophet (ﷺ) many times say: When a servant of Allah is accustomed to do a good work, then becomes ill or goes on journey, what was accustomed to do when he was well and staying at home will be recorded for him}}
\hadithdefcmd{abudawud}{3092}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، عَنْ أَبِي عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أُمِّ الْعَلاَءِ، قَالَتْ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَرِيضَةٌ فَقَالَ ‏ "‏ أَبْشِرِي يَا أُمَّ الْعَلاَءِ فَإِنَّ مَرَضَ الْمُسْلِمِ يُذْهِبُ اللَّهُ بِهِ خَطَايَاهُ كَمَا تُذْهِبُ النَّارُ خَبَثَ الذَّهَبِ وَالْفِضَّةِ ‏"‏ ‏.‏\hadithno{3092}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm al-Ala: The Messenger of Allah (ﷺ) visited me while I was sick. He said: Be glad, Umm al-Ala' for Allah removes the sins of a Muslim for his illness as fire removes the dross of gold and silver}}
\hadithdefcmd{abudawud}{3093}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، - قَالَ أَبُو دَاوُدَ وَهَذَا لَفْظُ ابْنِ بَشَّارٍ - عَنْ أَبِي عَامِرٍ الْخَزَّازِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي لأَعْلَمُ أَشَدَّ آيَةٍ فِي الْقُرْآنِ قَالَ ‏"‏ أَيَّةُ آيَةٍ يَا عَائِشَةُ ‏"‏ ‏.‏ قَالَتْ قَوْلُ اللَّهِ تَعَالَى ‏\{‏ مَنْ يَعْمَلْ سُوءًا يُجْزَ بِهِ ‏\}‏ قَالَ ‏"‏ أَمَا عَلِمْتِ يَا عَائِشَةُ أَنَّ الْمُؤْمِنَ تُصِيبُهُ النَّكْبَةُ أَوِ الشَّوْكَةُ فَيُكَافَأُ بِأَسْوَإِ عَمَلِهِ وَمَنْ حُوسِبَ عُذِّبَ ‏"‏ ‏.‏ قَالَتْ أَلَيْسَ اللَّهُ يَقُولُ ‏\{‏ فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا ‏\}‏ قَالَ ‏"‏ ذَاكُمُ الْعَرْضُ يَا عَائِشَةُ مَنْ نُوقِشَ الْحِسَابَ عُذِّبَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا لَفْظُ ابْنِ بَشَّارٍ قَالَ أَخْبَرَنَا ابْنُ أَبِي مُلَيْكَةَ ‏.‏\hadithno{3093}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah: I said: Messenger of Allah, I know the severest verse in the Qur'an. He asked: What is that verse. A'ishah? She replied: Allah's words: "If anyone does evil, he will be requited for it." He said: Do you know A'ishah, that when a believer is afflicted with a calamity or a thorn, it serves as an atonement for his evil deed. He who is called to account will be punished. She said: Does Allah not say: "He truly will recieve an easy reckoning." He said: This is the presentation, A'ishah. If anyone criticized in reckoning, he will be punished. Abu Dawud said: This is the version of Ibn Bashshar. He said: Ibn Abi Mulaikah narrated to us}}
\hadithdefcmd{abudawud}{3094}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ فَلَمَّا دَخَلَ عَلَيْهِ عَرَفَ فِيهِ الْمَوْتَ قَالَ ‏ "‏ قَدْ كُنْتُ أَنْهَاكَ عَنْ حُبِّ يَهُودَ ‏"‏ ‏.‏ قَالَ فَقَدْ أَبْغَضَهُمْ أَسْعَدُ بْنُ زُرَارَةَ فَمَهْ فَلَمَّا مَاتَ أَتَاهُ ابْنُهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ عَبْدَ اللَّهِ بْنَ أُبَىٍّ قَدْ مَاتَ فَأَعْطِنِي قَمِيصَكَ أُكَفِّنْهُ فِيهِ ‏.‏ فَنَزَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَمِيصَهُ فَأَعْطَاهُ إِيَّاهُ ‏.‏\hadithno{3094}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Usamah b. Zaid:The Messenger of Allah (ﷺ) went out to visit 'Abd Allah b. Ubayy during his illness of which he died. When he entered upon him, he realised death on him. He said: I used to forbid you from the love of Jews. He ('Abd Allah) said: As'ad b. Zurarah hated them. So what (the benefited) ? When he died, his son came and said: Prophet of Allah, 'Abd Allah b. Ubayy has died, give me your shirt, so that I shroud him in it. The Messenger of Allah (ﷺ) took off his shirt and gave it to him}}
\hadithdefcmd{abudawud}{3095}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ غُلاَمًا، مِنَ الْيَهُودِ كَانَ مَرِضَ فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ فَقَعَدَ عِنْدَ رَأْسِهِ فَقَالَ لَهُ ‏"‏ أَسْلِمْ ‏"‏ ‏.‏ فَنَظَرَ إِلَى أَبِيهِ وَهُوَ عِنْدَ رَأْسِهِ فَقَالَ لَهُ أَبُوهُ أَطِعْ أَبَا الْقَاسِمِ ‏.‏ فَأَسْلَمَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَنْقَذَهُ بِي مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3095}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5657)}\hadithtrans{Narrated Anas :A young Jew became ill. The Prophet (ﷺ) went to visit him. He sat down by his head and said to him: Accept Islam. He looked at his father who was beside him near his head, and he said: Obey Abu al-Qasim. So he accepted Islam, and the Prophet (ﷺ) stood up saying: Praise be to Allah Who has saved him through me from Hell}}
\hadithdefcmd{abudawud}{3096}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي لَيْسَ بِرَاكِبِ بَغْلٍ وَلاَ بِرْذَوْنٍ ‏.‏\hadithno{3096}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5664)}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) would visit me (during my illness) riding neither a mule nor a pony}}
\hadithdefcmd{abudawud}{3097}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا الرَّبِيعُ بْنُ رَوْحِ بْنِ خُلَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، حَدَّثَنَا الْفَضْلُ بْنُ دَلْهَمٍ الْوَاسِطِيُّ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ وَعَادَ أَخَاهُ الْمُسْلِمَ مُحْتَسِبًا بُوعِدَ مِنْ جَهَنَّمَ مَسِيرَةَ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏ قُلْتُ يَا أَبَا حَمْزَةَ وَمَا الْخَرِيفُ قَالَ الْعَامُ ‏.‏ قَالَ أَبُو دَاوُدَ وَالَّذِي تَفَرَّدَ بِهِ الْبَصْرِيُّونَ مِنْهُ الْعِيَادَةُ وَهُوَ مُتَوَضِّئٌ ‏.‏\hadithno{3097}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: If anyone performs ablution well and pays a visit to his (sick) Muslim brother seeking his reward from Allah, he will be removed a distance of seventy years (kharif) from Hell. I asked: What is kharif, Abu Hamzah? He replied: A year. Abu Dawud said: Only the people of Basrah have narrated the tradition on visiting the sick after performing ablution}}
\hadithdefcmd{abudawud}{3098}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ اللَّهِ بْنِ نَافِعٍ، عَنْ عَلِيٍّ، قَالَ مَا مِنْ رَجُلٍ يَعُودُ مَرِيضًا مُمْسِيًا إِلاَّ خَرَجَ مَعَهُ سَبْعُونَ أَلْفَ مَلَكٍ يَسْتَغْفِرُونَ لَهُ حَتَّى يُصْبِحَ وَكَانَ لَهُ خَرِيفٌ فِي الْجَنَّةِ وَمَنْ أَتَاهُ مُصْبِحًا خَرَجَ مَعَهُ سَبْعُونَ أَلْفَ مَلَكٍ يَسْتَغْفِرُونَ لَهُ حَتَّى يُمْسِيَ وَكَانَ لَهُ خَرِيفٌ فِي الْجَنَّةِ ‏.‏\hadithno{3098}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ali:If a man visits a patient in the evening, seventy thousand angels come along with him seeking forgiveness from Allah for him till the morning, and he will have a garden in the Paradise}}
\hadithdefcmd{abudawud}{3099}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ لَمْ يَذْكُرِ الْخَرِيفَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ مَنْصُورٌ عَنِ الْحَكَمِ أَبِي حَفْصٍ كَمَا رَوَاهُ شُعْبَةُ ‏.‏\hadithno{3099}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by 'Ali from the Prophet (ﷺ) through a different chain of narrators to the same effect. This version does not mention the word "garden" (khartf). Abu Dawud said:This tradition has been narrated by Mansur from al-Hakkam as narrated by Shu'bah}}
\hadithdefcmd{abudawud}{3100}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ أَبِي جَعْفَرٍ عَبْدِ اللَّهِ بْنِ نَافِعٍ، قَالَ - وَكَانَ نَافِعٌ غُلاَمَ الْحَسَنِ بْنِ عَلِيٍّ - قَالَ جَاءَ أَبُو مُوسَى إِلَى الْحَسَنِ بْنِ عَلِيٍّ يَعُودُهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَاقَ مَعْنَى حَدِيثِ شُعْبَةَ ‏.‏ قَالَ أَبُو دَاوُدَ أُسْنِدَ هَذَا عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ صَحِيحٍ ‏.‏\hadithno{3100}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Ja'far 'Abd Allah b. Nafi', the slave of al-Hasan b. 'Ali: Abu Musa paid a sick visit to al-Hasan b. 'Ali. Abu Dawud said: He narrated the tradition to the same effect as narrated by Shu'bah. Abu Dawud said: This tradition has been transmitted by 'Ali from the Prophet (ﷺ) without any sound manner}}
\hadithdefcmd{abudawud}{3101}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أُصِيبَ سَعْدُ بْنُ مُعَاذٍ يَوْمَ الْخَنْدَقِ رَمَاهُ رَجُلٌ فِي الأَكْحَلِ فَضَرَبَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْمَةً فِي الْمَسْجِدِ فَيَعُودُهُ مِنْ قَرِيبٍ ‏.‏\hadithno{3101}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (463) Sahih Muslim (1769)}\hadithtrans{Narrated 'Aishah:When Sa'd b. Mu'adh suffered affliction on the day of Trench (i.e. the battle of Trench) a man shot an arrow in the vein of his hand. The Messenger of Allah (ﷺ) pitched a tent for him the mosque so that he might visit him from near}}
\hadithdefcmd{abudawud}{3102}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ وَجَعٍ كَانَ بِعَيْنَىَّ ‏.‏\hadithno{3102}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zayd ibn Arqam: The Messenger of Allah (ﷺ) visited me while I was suffering from pain in my eyes}}
\hadithdefcmd{abudawud}{3103}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَمِعْتُمْ بِهِ بِأَرْضٍ فَلاَ تُقْدِمُوا عَلَيْهِ وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏ ‏.‏ يَعْنِي الطَّاعُونَ ‏.‏\hadithno{3103}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5729) Sahih Muslim (2219)}\hadithtrans{Narrated 'Abd Allah b. 'Abbas:That 'Abd al-Rahman b.'Awf said: I heard the Messenger of Allah (ﷺ) say: When you hear that it is breaking out in a certain territory, do not go there. If it breaks out in the territory you are in, do not go out fleeing away from it. By "it" he referred to the plague}}
\hadithdefcmd{abudawud}{3104}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْجُعَيْدُ، عَنْ عَائِشَةَ بِنْتِ سَعْدٍ، أَنَّ أَبَاهَا، قَالَ اشْتَكَيْتُ بِمَكَّةَ فَجَاءَنِي النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي وَوَضَعَ يَدَهُ عَلَى جَبْهَتِي ثُمَّ مَسَحَ صَدْرِي وَبَطْنِي ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ اشْفِ سَعْدًا وَأَتْمِمْ لَهُ هِجْرَتَهُ ‏"‏ ‏.‏\hadithno{3104}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5659)}\hadithtrans{Narrated 'Aishah daughter of Sa'd:That her father said: I had a complaint at Mecca. The Messenger of Allah (ﷺ) came to pay a sick-visit to me. He put his hand on my forehead, wiped my chest and belly, and then said: O Allah! heal up Sa'd and complete his immigration}}
\hadithdefcmd{abudawud}{3105}{حَدَّثَنَا ابْنُ كَثِيرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَطْعِمُوا الْجَائِعَ وَعُودُوا الْمَرِيضَ وَفُكُّوا الْعَانِيَ ‏"‏ ‏.‏ قَالَ سُفْيَانُ وَالْعَانِي الأَسِيرُ ‏.‏\hadithno{3105}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5373)}\hadithtrans{Narrated Abu Musa Al-Ash'ari:The Messenger of Allah (ﷺ) as saying: Feed the hungry, visit the sick and free the captive. Sufyan said: al-'ani means captive}}
\hadithdefcmd{abudawud}{3106}{حَدَّثَنَا الرَّبِيعُ بْنُ يَحْيَى، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا يَزِيدُ أَبُو خَالِدٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ عَادَ مَرِيضًا لَمْ يَحْضُرْ أَجَلُهُ فَقَالَ عِنْدَهُ سَبْعَ مِرَارٍ أَسْأَلُ اللَّهَ الْعَظِيمَ رَبَّ الْعَرْشِ الْعَظِيمِ أَنْ يَشْفِيَكَ إِلاَّ عَافَاهُ اللَّهُ مِنْ ذَلِكَ الْمَرَضِ ‏"‏ ‏.‏\hadithno{3106}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone visits a sick whose time (of death) has not come, and says with him seven times: I ask Allah, the Mighty, the Lord of the mighty Throne, to cure you, Allah will cure him from that disease}}
\hadithdefcmd{abudawud}{3107}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حُيَىِّ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنِ ابْنِ عَمْرٍو، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا جَاءَ الرَّجُلُ يَعُودُ مَرِيضًا فَلْيَقُلِ اللَّهُمَّ اشْفِ عَبْدَكَ يَنْكَأُ لَكَ عَدُوًّا أَوْ يَمْشِي لَكَ إِلَى جَنَازَةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ ابْنُ السَّرْحِ ‏"‏ إِلَى صَلاَةٍ ‏"‏ ‏.‏\hadithno{3107}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: When a man comes to visit a sick person, he should say: O Allah, cure Thy servant, who may then wreak havoc on an enemy for your sake, or walk at a funeral for your sake. Abu Dawud said: Ibn As-Sarh (one of the narrators) said: "Ilas-salat (To the Salat)}}
\hadithdefcmd{abudawud}{3108}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَدْعُوَنَّ أَحَدُكُمْ بِالْمَوْتِ لِضُرٍّ نَزَلَ بِهِ وَلَكِنْ لِيَقُلِ اللَّهُمَّ أَحْيِنِي مَا كَانَتِ الْحَيَاةُ خَيْرًا لِي وَتَوَفَّنِي إِذَا كَانَتِ الْوَفَاةُ خَيْرًا لِي ‏"‏ ‏.‏\hadithno{3108}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (6351) Sahih Muslim (2680)}\hadithtrans{Narrated Anas:The Messenger of Allah (ﷺ) as saying: No one of you should wish for death for any calamity that befalls him, but he should say: O Allah! cause me to live so long as my life is better for me ; and cause me to die where death is better for me}}
\hadithdefcmd{abudawud}{3109}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَمَنَّيَنَّ أَحَدُكُمُ الْمَوْتَ ‏"‏ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{3109}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) as saying: No one of you should wish for death. He then mentioned the rest of the tradition in a similar manner}}
\hadithdefcmd{abudawud}{3110}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، أَوْ سَعْدِ بْنِ عُبَيْدَةَ عَنْ عُبَيْدِ بْنِ خَالِدٍ السُّلَمِيِّ، - رَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ مَرَّةً عَنِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَالَ مَرَّةً عَنْ عُبَيْدٍ - قَالَ ‏ "‏ مَوْتُ الْفَجْأَةِ أَخْذَةُ أَسَفٍ ‏"‏ ‏.‏\hadithno{3110}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ubayd ibn Khalid as-Sulami,: A man from the Companions of the Prophet (ﷺ), said: The narrator Sa'd ibn Ubaydah narrated sometimes from the Prophet (ﷺ) and sometimes as a statement of Ubayd (ibn Khalid): The Prophet (ﷺ) said: Sudden death is a wrathful catching}}
\hadithdefcmd{abudawud}{3111}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ عَتِيكِ بْنِ الْحَارِثِ بْنِ عَتِيكٍ، - وَهُوَ جَدُّ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ أَبُو أُمِّهِ - أَنَّهُ أَخْبَرَهُ أَنَّ عَمَّهُ جَابِرَ بْنَ عَتِيكٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَ يَعُودُ عَبْدَ اللَّهِ بْنَ ثَابِتٍ فَوَجَدَهُ قَدْ غُلِبَ فَصَاحَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يُجِبْهُ فَاسْتَرْجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ غُلِبْنَا عَلَيْكَ يَا أَبَا الرَّبِيعِ ‏"‏ ‏.‏ فَصَاحَ النِّسْوَةُ وَبَكَيْنَ فَجَعَلَ ابْنُ عَتِيكٍ يُسْكِتُهُنَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهُنَّ فَإِذَا وَجَبَ فَلاَ تَبْكِيَنَّ بَاكِيَةٌ ‏"‏ ‏.‏ قَالُوا وَمَا الْوُجُوبُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْمَوْتُ ‏"‏ ‏.‏ قَالَتِ ابْنَتُهُ وَاللَّهِ إِنْ كُنْتُ لأَرْجُو أَنْ تَكُونَ شَهِيدًا فَإِنَّكَ كُنْتَ قَدْ قَضَيْتَ جِهَازَكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ أَوْقَعَ أَجْرَهُ عَلَى قَدْرِ نِيَّتِهِ وَمَا تَعُدُّونَ الشَّهَادَةَ ‏"‏ ‏.‏ قَالُوا الْقَتْلَ فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الشَّهَادَةُ سَبْعٌ سِوَى الْقَتْلِ فِي سَبِيلِ اللَّهِ الْمَطْعُونُ شَهِيدٌ وَالْغَرِقُ شَهِيدٌ وَصَاحِبُ ذَاتِ الْجَنْبِ شَهِيدٌ وَالْمَبْطُونُ شَهِيدٌ وَصَاحِبُ الْحَرِيقِ شَهِيدٌ وَالَّذِي يَمُوتُ تَحْتَ الْهَدْمِ شَهِيدٌ وَالْمَرْأَةُ تَمُوتُ بِجُمْعٍ شَهِيدٌ ‏"‏ ‏.‏\hadithno{3111}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Atik: The Messenger of Allah (ﷺ) came to visit Abdullah ibn Thabit who was ill. He found that he was dominated (by the divine decree). The Messenger of Allah (ﷺ) called him loudly, but he did not respond. He uttered the Qur'anic verse "We belong to Allah and to Him do we return" and he said: We have been dominated against you, AburRabi'. Then the women cried and wept, and Ibn Atik began to silence them. The Messenger of Allah (ﷺ) said: Leave them, when the divine decree is made, no woman should weep. They (the people) asked: What is necessary happening, Messenger of Allah? He replied: Death. His daughter said: I hope you will be a martyr, for you have completed your preparations for jihad. The Messenger of Allah (ﷺ) said: Allah Most High gave him a reward according to his intentions. What do you consider martyrdom? They said: Being killed in the cause of Allah. The Messenger of Allah (ﷺ) said: There are seven types of martyrdom in addition to being killed in Allah's cause: one who dies of plague is a martyr; one who is drowned is a martyr; one who dies of pleurisy is a martyr; one who dies of an internal complaint is a martyr; one who is burnt to death is a martyr; who one is killed by a building falling on him is a martyr; and a woman who dies while pregnant is a martyr}}
\hadithdefcmd{abudawud}{3112}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، أَخْبَرَنِي عُمَرُ بْنُ جَارِيَةَ الثَّقَفِيُّ، حَلِيفُ بَنِي زُهْرَةَ - وَكَانَ مِنْ أَصْحَابِ أَبِي هُرَيْرَةَ - عَنْ أَبِي هُرَيْرَةَ، قَالَ ابْتَاعَ بَنُو الْحَارِثِ بْنِ عَامِرِ بْنِ نَوْفَلٍ خُبَيْبًا - وَكَانَ خُبَيْبٌ هُوَ قَتَلَ الْحَارِثَ بْنَ عَامِرٍ يَوْمَ بَدْرٍ - فَلَبِثَ خُبَيْبٌ عِنْدَهُمْ أَسِيرًا حَتَّى أَجْمَعُوا لِقَتْلِهِ فَاسْتَعَارَ مِنَ ابْنَةِ الْحَارِثِ مُوسَى يَسْتَحِدُّ بِهَا فَأَعَارَتْهُ فَدَرَجَ بُنَىٌّ لَهَا وَهِيَ غَافِلَةٌ حَتَّى أَتَتْهُ فَوَجَدَتْهُ مُخْلِيًا وَهُوَ عَلَى فَخِذِهِ وَالْمُوسَى بِيَدِهِ فَفَزِعَتْ فَزْعَةً عَرَفَهَا فِيهَا فَقَالَ أَتَخْشَيْنَ أَنْ أَقْتُلَهُ مَا كُنْتُ لأَفْعَلَ ذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذِهِ الْقِصَّةَ شُعَيْبُ بْنُ أَبِي حَمْزَةَ عَنِ الزُّهْرِيِّ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عِيَاضٍ أَنَّ ابْنَةَ الْحَارِثِ أَخْبَرَتْهُ أَنَّهُمْ حِينَ اجْتَمَعُوا - يَعْنِي لِقَتْلِهِ - اسْتَعَارَ مِنْهَا مُوسَى يَسْتَحِدُّ بِهَا فَأَعَارَتْهُ ‏.‏\hadithno{3112}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3989، 3045)}\hadithtrans{Narrated Abu Hurairah: Banu al-Harith b. 'Amir b. Nawfal bought Khubaib. Khubaib killed al-Harith b. 'Amir on the day of Badr. Khubaib remained with them as a prisoner until they agreed on his killing. He borrowed razor form the daughter of al-Harith to shave his pubes. She let it to him. A small child of her crept to him while she was inattentive. When she same, she found him alone and the child was on this thigh and the razor was in his hand. She was terrified and he realized its effect on her. He said: Do you fear that I shall kill him ? I am not going to do that. Abu Dawud said: Shu'aib b. Abi Hamzah transmitted this narrative from al-Zuhri. He said: 'Ubaid Allah b. 'Ayyash told me that the daughter of al-Harith told him that when they gathered for killing him, he borrowed a razor from her to shave (his pubes). She lent it to him}}
\hadithdefcmd{abudawud}{3113}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ قَبْلَ مَوْتِهِ بِثَلاَثٍ قَالَ ‏ "‏ لاَ يَمُوتُ أَحَدُكُمْ إِلاَّ وَهُوَ يُحْسِنُ الظَّنَّ بِاللَّهِ ‏"‏ ‏.‏\hadithno{3113}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2877)}\hadithtrans{Narrated Jabir b. 'Abd Allah :I heard the Messenger of Allah (ﷺ) say three days before his death: No one of you dies but he had good faith in Allah}}
\hadithdefcmd{abudawud}{3114}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ لَمَّا حَضَرَهُ الْمَوْتُ دَعَا بِثِيَابٍ جُدُدٍ فَلَبِسَهَا ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْمَيِّتَ يُبْعَثُ فِي ثِيَابِهِ الَّتِي يَمُوتُ فِيهَا ‏"‏ ‏.‏\hadithno{3114}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: When the time of his death came, he called for new clothes and put on them. He then said: I heard the Messenger of Allah (ﷺ) say: A deceased will be raised in the clothes in which he died}}
\hadithdefcmd{abudawud}{3115}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا حَضَرْتُمُ الْمَيِّتَ فَقُولُوا خَيْرًا فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ فَلَمَّا مَاتَ أَبُو سَلَمَةَ قُلْتُ يَا رَسُولَ اللَّهِ مَا أَقُولُ قَالَ ‏"‏ قُولِي اللَّهُمَّ اغْفِرْ لَهُ وَأَعْقِبْنَا عُقْبَى صَالِحَةً ‏"‏ ‏.‏ قَالَتْ فَأَعْقَبَنِي اللَّهُ تَعَالَى بِهِ مُحَمَّدًا صلى الله عليه وسلم ‏.‏\hadithno{3115}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (919)}\hadithtrans{Narrated Umm Salamah:The Messenger of Allah (ﷺ): When you attend dying man, you should say good words, for the angels say Amin to what you say. When Abu Salamah died, I said: What should I say, Messenger of Allah? He said: O Allah forgive him, and give us something good in exchange. She said: So Allah gave me Muhammad (ﷺ) in exchange for him}}
\hadithdefcmd{abudawud}{3116}{حَدَّثَنَا مَالِكُ بْنُ عَبْدِ الْوَاحِدِ الْمِسْمَعِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنِي صَالِحُ بْنُ أَبِي عَرِيبٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ آخِرُ كَلاَمِهِ لاَ إِلَهَ إِلاَّ اللَّهُ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3116}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu’adh bin Jabal :The Messenger of Allah (ﷺ) as saying: If anyone's last words are "There is no god but Allah" he will enter Paradise}}
\hadithdefcmd{abudawud}{3117}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، حَدَّثَنَا يَحْيَى بْنُ عُمَارَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقِّنُوا مَوْتَاكُمْ قَوْلَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{3117}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (916)}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) as saying: Recite to those of you who are dying "There is no god but Allah}}
\hadithdefcmd{abudawud}{3118}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ حَبِيبٍ أَبُو مَرْوَانَ، حَدَّثَنَا أَبُو إِسْحَاقَ، - يَعْنِي الْفَزَارِيَّ - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَبِي سَلَمَةَ وَقَدْ شَقَّ بَصَرُهُ فَأَغْمَضَهُ فَصَيَّحَ نَاسٌ مِنْ أَهْلِهِ فَقَالَ ‏"‏ لاَ تَدْعُوا عَلَى أَنْفُسِكُمْ إِلاَّ بِخَيْرٍ فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لأَبِي سَلَمَةَ وَارْفَعْ دَرَجَتَهُ فِي الْمَهْدِيِّينَ وَاخْلُفْهُ فِي عَقِبِهِ فِي الْغَابِرِينَ وَاغْفِرْ لَنَا وَلَهُ رَبَّ الْعَالَمِينَ اللَّهُمَّ افْسَحْ لَهُ فِي قَبْرِهِ وَنَوِّرْ لَهُ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَتَغْمِيضُ الْمَيِّتِ بَعْدَ خُرُوجِ الرُّوحِ سَمِعْتُ مُحَمَّدَ بْنَ مُحَمَّدِ بْنِ النُّعْمَانِ الْمُقْرِئَ قَالَ سَمِعْتُ أَبَا مَيْسَرَةَ رَجُلاً عَابِدًا يَقُولُ غَمَّضْتُ جَعْفَرًا الْمُعَلِّمَ وَكَانَ رَجُلاً عَابِدًا فِي حَالَةِ الْمَوْتِ فَرَأَيْتُهُ فِي مَنَامِي لَيْلَةَ مَاتَ يَقُولُ أَعْظَمُ مَا كَانَ عَلَىَّ تَغْمِيضُكَ لِي قَبْلَ أَنْ أَمُوتَ ‏.‏\hadithno{3118}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (920)}\hadithtrans{Narrated Umm Salamah: When the Messenger of Allah (ﷺ) entered upon Abu Salamah, his eyes were fixedly open. So he closed them. The members of his family cried. He said: Do not pray for yourself anything but good, for the angels utter Amin to what you say. He then said: O Allah, forgive Abu Salamah, raise his rank among those who are guided, and grant him a succession in his descendants who remain. Forgive both us and him, Lord of the universe. O Allah,make his grave spacious for him, and grant him light in it. Abu Dawud said: The eyes of the deceased should be closed after his expiry. I heard Muhammad b. al-Nu'man al-Muqri say: I heard a man who was devoted to Allah say: I closed the eyes of Ja'far al-Mu'allim when he was dying. He was a man devoted to Allah. I saw him in a dream on the night he died. He said: The biggest thing for me was closing the eyes by you before I died}}
\hadithdefcmd{abudawud}{3119}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنِ ابْنِ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَصَابَتْ أَحَدَكُمْ مُصِيبَةٌ فَلْيَقُلْ ‏\{‏ إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ ‏\}‏ اللَّهُمَّ عِنْدَكَ أَحْتَسِبُ مُصِيبَتِي فَآجِرْنِي فِيهَا وَأَبْدِلْ لِي خَيْرًا مِنْهَا ‏"‏ ‏.‏\hadithno{3119}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah:The Messenger of Allah (ﷺ) as saying: When one of you is afflicted with a calamity, he should say: "We belong to Allah, and to Him we do return." O Allah, I expect reward from Thee from this affliction, so give me reward for it, and give me a better compensation}}
\hadithdefcmd{abudawud}{3120}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُجِّيَ فِي ثَوْبٍ حِبَرَةٍ ‏.‏\hadithno{3120}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5814) Sahih Muslim (942)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) was covered with striped Yemen garment (after his death)}}
\hadithdefcmd{abudawud}{3121}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَمُحَمَّدُ بْنُ مَكِّيٍّ الْمَرْوَزِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، - وَلَيْسَ بِالنَّهْدِيِّ - عَنْ أَبِيهِ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اقْرَءُوا ‏\{‏ يس ‏\}‏ عَلَى مَوْتَاكُمْ ‏"‏ ‏.‏ وَهَذَا لَفْظُ ابْنِ الْعَلاَءِ ‏.‏\hadithno{3121}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ma'qil ibn Yasar: The Prophet (ﷺ) said: Recite Surah Ya-Sin over your dying men. This is the version of Ibn al-Ala}}
\hadithdefcmd{abudawud}{3122}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا قُتِلَ زَيْدُ بْنُ حَارِثَةَ وَجَعْفَرٌ وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ يُعْرَفُ فِي وَجْهِهِ الْحُزْنُ وَذَكَرَ الْقِصَّةَ ‏.‏\hadithno{3122}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1305) Sahih Muslim (935)}\hadithtrans{Narrated 'Aishah:When Zaid b. Harithah, Ja'far and 'Abd Allah b. Rawahah were killed, the Messenger of Allah (ﷺ) sat down in the mosque and grief was visible in his face. Then he (the narrator) mentioned the rest of the tradition}}
\hadithdefcmd{abudawud}{3123}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، حَدَّثَنَا الْمُفَضَّلُ، عَنْ رَبِيعَةَ بْنِ سَيْفٍ الْمَعَافِرِيِّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ قَبَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم - يَعْنِي مَيِّتًا - فَلَمَّا فَرَغْنَا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَانْصَرَفْنَا مَعَهُ فَلَمَّا حَاذَى بَابَهُ وَقَفَ فَإِذَا نَحْنُ بِامْرَأَةٍ مُقْبِلَةٍ - قَالَ أَظُنُّهُ عَرَفَهَا - فَلَمَّا ذَهَبَتْ إِذَا هِيَ فَاطِمَةُ - عَلَيْهَا السَّلاَمُ - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَخْرَجَكِ يَا فَاطِمَةُ مِنْ بَيْتِكِ ‏"‏ ‏.‏ فَقَالَتْ أَتَيْتُ يَا رَسُولَ اللَّهِ أَهْلَ هَذَا الْبَيْتِ فَرَحَّمْتُ إِلَيْهِمْ مَيِّتَهُمْ أَوْ عَزَّيْتُهُمْ بِهِ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلَعَلَّكِ بَلَغْتِ مَعَهُمُ الْكُدَى ‏"‏ ‏.‏ قَالَتْ مَعَاذَ اللَّهِ وَقَدْ سَمِعْتُكَ تَذْكُرُ فِيهَا مَا تَذْكُرُ ‏.‏ قَالَ ‏"‏ لَوْ بَلَغْتِ مَعَهُمُ الْكُدَى ‏"‏ ‏.‏ فَذَكَرَ تَشْدِيدًا فِي ذَلِكَ فَسَأَلْتُ رَبِيعَةَ عَنِ الْكُدَى فَقَالَ الْقُبُورُ فِيمَا أَحْسِبُ ‏.‏\hadithno{3123}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: We buried a deceased person in the company of the Messenger of Allah (ﷺ). When we had finished, the Messenger of Allah (ﷺ) returned and we also returned with him. When he approached his door, he stopped, and we saw a woman coming towards him. He (the narrator) said: I think he recognized her. When she went away, we came to know that she was Fatimah. The Messenger of Allah (ﷺ) said to her: What brought you out of your house, Fatimah? She replied: I came to the people of this house, Messenger of Allah, and I showed pity and expressed my condolences to them for their deceased relation. The Messenger of Allah (ﷺ) said: You might have gone to the graveyard with them. She replied: I seek refuge in Allah! I heard you referring to what you mentioned. He said: If you had gone to the graveyard...He then mentioned severe words about it. I then asked Rabi'ah (a narrator of this tradition) about al-kuda (stony land). He replied: I think it means the graves}}
\hadithdefcmd{abudawud}{3124}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ أَتَى نَبِيُّ اللَّهِ صلى الله عليه وسلم عَلَى امْرَأَةٍ تَبْكِي عَلَى صَبِيٍّ لَهَا فَقَالَ لَهَا ‏"‏ اتَّقِي اللَّهَ وَاصْبِرِي ‏"‏ ‏.‏ فَقَالَتْ وَمَا تُبَالِي أَنْتَ بِمُصِيبَتِي فَقِيلَ لَهَا هَذَا النَّبِيُّ صلى الله عليه وسلم ‏.‏ فَأَتَتْهُ فَلَمْ تَجِدْ عَلَى بَابِهِ بَوَّابِينَ فَقَالَتْ يَا رَسُولَ اللَّهِ لَمْ أَعْرِفْكَ فَقَالَ ‏"‏ إِنَّمَا الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏ أَوْ ‏"‏ عِنْدَ أَوَّلِ صَدْمَةٍ ‏"‏ ‏.‏\hadithno{3124}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1252) Sahih Muslim (926)}\hadithtrans{Narrated Anas:The Prophet (ﷺ) came upon a woman who was weeping for her child. He said to her: Fear Allah and have patience. She said: What have you to do with my calamity ? She was then told that he was the Prophet (ﷺ). She, therefore, came to him. She did not find doorkeepers at his gate. She said: I did not recognize you, Messenger of Allah. He said: Endurance is shown only at a first blow}}
\hadithdefcmd{abudawud}{3125}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ الأَحْوَلِ، قَالَ سَمِعْتُ أَبَا عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ ابْنَةً لِرَسُولِ اللَّهِ، صلى الله عليه وسلم أَرْسَلَتْ إِلَيْهِ وَأَنَا مَعَهُ وَسَعْدٌ وَأَحْسِبُ أُبَيًّا أَنَّ ابْنِي أَوْ بِنْتِي قَدْ حُضِرَ فَاشْهَدْنَا ‏.‏ فَأَرْسَلَ يُقْرِئُ السَّلاَمَ فَقَالَ ‏"‏ قُلْ لِلَّهِ مَا أَخَذَ وَمَا أَعْطَى وَكُلُّ شَىْءٍ عِنْدَهُ إِلَى أَجَلٍ ‏"‏ ‏.‏ فَأَرْسَلَتْ تُقْسِمُ عَلَيْهِ فَأَتَاهَا فَوُضِعَ الصَّبِيُّ فِي حِجْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَفْسُهُ تَقَعْقَعُ فَفَاضَتْ عَيْنَا رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ سَعْدٌ مَا هَذَا قَالَ ‏"‏ إِنَّهَا رَحْمَةٌ وَضَعَهَا اللَّهُ فِي قُلُوبِ مَنْ يَشَاءُ وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏ ‏.‏\hadithno{3125}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1284) Sahih Muslim (923)}\hadithtrans{Narrated Usamah b. Zaid:A daughter of Messenger of Allah (ﷺ) sent him message while I and Sa'd were with him and I think Ubayy was also there: My son or daughter (the narrator is doubtful) is dying, so come to us. He sent her greeting, saying at the same time: Say! What Allah has been taken belongs to Him, what He has given (belongs to Him), and He has appointed time for everything. She then sent a message adjuring him (to come to her). So he came to her and the child who was on the point of death was placed in the hearts of those whom He wished. Allah shows compassion only to those of His servants who are compassionate}}
\hadithdefcmd{abudawud}{3126}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وُلِدَ لِيَ اللَّيْلَةَ غُلاَمٌ فَسَمَّيْتُهُ بِاسْمِ أَبِي إِبْرَاهِيمَ ‏"‏ ‏.‏ فَذَكَرَ الْحَدِيثَ قَالَ أَنَسٌ لَقَدْ رَأَيْتُهُ يَكِيدُ بِنَفْسِهِ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَمَعَتْ عَيْنَا رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ تَدْمَعُ الْعَيْنُ وَيَحْزَنُ الْقَلْبُ وَلاَ نَقُولُ إِلاَّ مَا يَرْضَى رَبُّنَا إِنَّا بِكَ يَا إِبْرَاهِيمُ لَمَحْزُونُونَ ‏"‏ ‏.‏\hadithno{3126}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2315)}\hadithtrans{Narrated Anas bin Malik:The Messenger of Allah (ﷺ) as saying: A child was born to me at night and I named him Ibrahim after his. He then narrated the rest of the tradition. Anas said: I saw it at the point of the death before the Messenger of Allah (ﷺ). Tears began to fall from the eyes of the Messenger of Allah (ﷺ). He said: The eye weeps and the heart grieves, but we say only what our Lord is pleased with, and we are grieved for you, Ibrahim}}
\hadithdefcmd{abudawud}{3127}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا عَنِ النِّيَاحَةِ ‏.‏\hadithno{3127}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7215)}\hadithtrans{Narrated Umm 'Atiyyah :The Messenger of Allah (ﷺ) prohibited us to wail}}
\hadithdefcmd{abudawud}{3128}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنْ مُحَمَّدِ بْنِ الْحَسَنِ بْنِ عَطِيَّةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّائِحَةَ وَالْمُسْتَمِعَةَ ‏.‏\hadithno{3128}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Messenger of Allah (ﷺ) cursed the wailing woman and the woman who listens to her}}
\hadithdefcmd{abudawud}{3129}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ عَبْدَةَ، وَأَبِي، مُعَاوِيَةَ - الْمَعْنَى - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَذُكِرَ ذَلِكَ لِعَائِشَةَ فَقَالَتْ وَهِلَ - تَعْنِي ابْنَ عُمَرَ - إِنَّمَا مَرَّ النَّبِيُّ صلى الله عليه وسلم عَلَى قَبْرٍ فَقَالَ ‏"‏ إِنَّ صَاحِبَ هَذَا لَيُعَذَّبُ وَأَهْلُهُ يَبْكُونَ عَلَيْهِ ‏"‏ ‏.‏ ثُمَّ قَرَأَتْ ‏\{‏ وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى ‏\}‏ قَالَ عَنْ أَبِي مُعَاوِيَةَ عَلَى قَبْرِ يَهُودِيٍّ ‏.‏\hadithno{3129}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3979، 3980، 3981) Sahih Muslim (932)}\hadithtrans{Narrated Ibn 'Umar: The Messenger of Allah (ﷺ) as saying: The dead is punished because of his family's weeping for him. When this was mentioned to 'Aishah, she said: Ibn 'Umar forgot and made a mistake. The Prophet (ﷺ) passed by grave and he said: The man in the grave is being punished while his family is weeping for him. She then recited: "No bearer of burdens can bear the burden of another." The narrator Abu Mu'awiyyah said: (The Prophet passed) by the grave of a Jew}}
\hadithdefcmd{abudawud}{3130}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ يَزِيدَ بْنِ أَوْسٍ، قَالَ دَخَلْتُ عَلَى أَبِي مُوسَى وَهُوَ ثَقِيلٌ فَذَهَبَتِ امْرَأَتُهُ لِتَبْكِي أَوْ تَهُمَّ بِهِ فَقَالَ لَهَا أَبُو مُوسَى أَمَا سَمِعْتِ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ بَلَى ‏.‏ قَالَ فَسَكَتَتْ فَلَمَّا مَاتَ أَبُو مُوسَى - قَالَ يَزِيدُ - لَقِيتُ الْمَرْأَةَ فَقُلْتُ لَهَا مَا قَوْلُ أَبِي مُوسَى لَكِ أَمَا سَمِعْتِ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ سَكَتِّ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ حَلَقَ وَمَنْ سَلَقَ وَمَنْ خَرَقَ ‏"‏ ‏.‏\hadithno{3130}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yazid ibn Aws said:I entered upon AbuMusa while he was at the point of death. His wife began to weep or was going to weep. AbuMusa said to her: Did you not hear what the Messenger of Allah (ﷺ) said? She said: Yes. The narrator said: She then kept silence. When AbuMusa died, Yazid said: I met the woman and asked her: What did AbuMusa mean when he said to you: Did you not hear what the Messenger of Allah (ﷺ) and the you kept silence? She replied: The Messenger of Allah (ﷺ) said: He who shaves (his head), shouts and tears his clothing does not belong to us}}
\hadithdefcmd{abudawud}{3131}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حُمَيْدُ بْنُ الأَسْوَدِ، حَدَّثَنَا الْحَجَّاجُ، - عَامِلٌ لِعُمَرَ بْنِ عَبْدِ الْعَزِيزِ عَلَى الرَّبَذَةِ حَدَّثَنِي أَسِيدُ بْنُ أَبِي أَسِيدٍ، عَنِ امْرَأَةٍ، مِنَ الْمُبَايِعَاتِ قَالَتْ كَانَ فِيمَا أَخَذَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَعْرُوفِ الَّذِي أَخَذَ عَلَيْنَا أَنْ لاَ نَعْصِيَهُ فِيهِ أَنْ لاَ نَخْمِشَ وَجْهًا وَلاَ نَدْعُوَ وَيْلاً وَلاَ نَشُقَّ جَيْبًا وَأَنْ لاَ نَنْشُرَ شَعْرًا ‏.‏\hadithno{3131}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Usayd ibn Abu Usayd, reported on the authority of a woman who took oath of allegiance (to the Prophet):One of the oaths which the Messenger of Allah (ﷺ) received from us about the virtue was that we would not disobey him in it (virtue): that we would not scratch the face, nor wail, nor tear the front of the garments nor dishevel the hair}}
\hadithdefcmd{abudawud}{3132}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي جَعْفَرُ بْنُ خَالِدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اصْنَعُوا لآلِ جَعْفَرٍ طَعَامًا فَإِنَّهُ قَدْ أَتَاهُمْ أَمْرٌ شَغَلَهُمْ ‏"‏ ‏.‏\hadithno{3132}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Ja'far: The Messenger of Allah (ﷺ) said: Prepare food for the family of Ja'far for there came upon them an incident which has engaged them}}
\hadithdefcmd{abudawud}{3133}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْجُشَمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رُمِيَ رَجُلٌ بِسَهْمٍ فِي صَدْرِهِ أَوْ فِي حَلْقِهِ فَمَاتَ فَأُدْرِجَ فِي ثِيَابِهِ كَمَا هُوَ - قَالَ - وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3133}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: A man had a shot of arrow in his chest or throat (the narrator is doubtful). So he died. He was shrouded in his clothes as he was. The narrator said: We were with the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3134}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، وَعِيسَى بْنُ يُونُسَ، قَالاَ حَدَّثَنَا عَلِيُّ بْنُ عَاصِمٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلَى أُحُدٍ أَنْ يُنْزَعَ عَنْهُمُ الْحَدِيدُ وَالْجُلُودُ وَأَنْ يُدْفَنُوا بِدِمَائِهِمْ وَثِيَابِهِمْ ‏.‏\hadithno{3134}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) commanded to remove weapons and skins from the martyrs of Uhud, and that they should be buried with their blood and clothes}}
\hadithdefcmd{abudawud}{3135}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، ح وَحَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، - وَهَذَا لَفْظُهُ - أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ اللَّيْثِيُّ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ أَنَّ أَنَسَ بْنَ مَالِكٍ حَدَّثَهُمْ أَنَّ شُهَدَاءَ أُحُدٍ لَمْ يُغَسَّلُوا وَدُفِنُوا بِدِمَائِهِمْ وَلَمْ يُصَلَّ عَلَيْهِمْ ‏.‏\hadithno{3135}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: The martyrs of Uhud were not washed, and they were buried with their blood. No prayer was offered over them}}
\hadithdefcmd{abudawud}{3136}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدٌ، - يَعْنِي ابْنَ الْحُبَابِ - ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو صَفْوَانَ، - يَعْنِي الْمَرْوَانِيَّ - عَنْ أُسَامَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، - الْمَعْنَى - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ عَلَى حَمْزَةَ وَقَدْ مُثِّلَ بِهِ فَقَالَ ‏"‏ لَوْلاَ أَنْ تَجِدَ صَفِيَّةُ فِي نَفْسِهَا لَتَرَكْتُهُ حَتَّى تَأْكُلَهُ الْعَافِيَةُ حَتَّى يُحْشَرَ مِنْ بُطُونِهَا ‏"‏ ‏.‏ وَقَلَّتِ الثِّيَابُ وَكَثُرَتِ الْقَتْلَى فَكَانَ الرَّجُلُ وَالرَّجُلاَنِ وَالثَّلاَثَةُ يُكَفَّنُونَ فِي الثَّوْبِ الْوَاحِدِ - زَادَ قُتَيْبَةُ - ثُمَّ يُدْفَنُونَ فِي قَبْرٍ وَاحِدٍ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْأَلُ ‏"‏ أَيُّهُمْ أَكْثَرُهُمْ قُرْآنًا ‏"‏ ‏.‏ فَيُقَدِّمُهُ إِلَى الْقِبْلَةِ ‏.‏\hadithno{3136}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) passed Hamzah who was killed and disfigured. He said: If Safiyyah were not grieved, I would have left him until the birds and beasts of prey would have eaten him, and he would have been resurrected from their bellies. The garments were scanty and the slain were in great number. So one, two and three persons were shrouded in one garment. The narrator Qutaybah added: They were then buried in one grave. The Messenger of Allah (ﷺ) asked: Which of the two learnt the Qur'an more? He then advanced him toward the qiblah (direction of prayer)}}
\hadithdefcmd{abudawud}{3137}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا أُسَامَةُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِحَمْزَةَ وَقَدْ مُثِّلَ بِهِ وَلَمْ يُصَلِّ عَلَى أَحَدٍ مِنَ الشُّهَدَاءِ غَيْرِهِ ‏.‏\hadithno{3137}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) passed by Hamzah who was disfigured (after being killed). He did not offer prayer over any martyr except him}}
\hadithdefcmd{abudawud}{3138}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ، أَنَّ اللَّيْثَ، حَدَّثَهُمْ عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ وَيَقُولُ ‏"‏ أَيُّهُمَا أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏ ‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمَا قَدَّمَهُ فِي اللَّحْدِ وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَأَمَرَ بِدَفْنِهِمْ بِدِمَائِهِمْ وَلَمْ يُغَسَّلُوا ‏.‏\hadithno{3138}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1343)}\hadithtrans{Narrated Jabir b. 'Abd Allah :The Messenger of Allah (ﷺ) combined two persons from among the martyrs of Uhud (in one garment), and said: Which of the two has learnt the Qur'an more ? When one of them was pointed to him, he advanced him in the grave, saying: I shall be witness to all these (martyrs) on the Day of Judgement. He then ordered them to be buried without being washed}}
\hadithdefcmd{abudawud}{3139}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ اللَّيْثِ، بِهَذَا الْحَدِيثِ بِمَعْنَاهُ قَالَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ‏.‏\hadithno{3139}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by al-Laith through a different chain of the same effect. This version adds:He combined two persons from among the martyrs of Uhud in one garment}}
\hadithdefcmd{abudawud}{3140}{حَدَّثَنَا عَلِيُّ بْنُ سَهْلٍ الرَّمْلِيُّ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أُخْبِرْتُ عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُبْرِزْ فَخِذَكَ وَلاَ تَنْظُرَنَّ إِلَى فَخِذِ حَىٍّ وَلاَ مَيِّتٍ ‏"‏ ‏.‏\hadithno{3140}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: Do not unveil your thigh, and do not look at the thigh of the living and the dead}}
\hadithdefcmd{abudawud}{3141}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي يَحْيَى بْنُ عَبَّادٍ، عَنْ أَبِيهِ، عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ قَالَ سَمِعْتُ عَائِشَةَ، تَقُولُ لَمَّا أَرَادُوا غَسْلَ النَّبِيِّ صلى الله عليه وسلم قَالُوا وَاللَّهِ مَا نَدْرِي أَنُجَرِّدُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ ثِيَابِهِ كَمَا نُجَرِّدُ مَوْتَانَا أَمْ نُغَسِّلُهُ وَعَلَيْهِ ثِيَابُهُ فَلَمَّا اخْتَلَفُوا أَلْقَى اللَّهُ عَلَيْهِمُ النَّوْمَ حَتَّى مَا مِنْهُمْ رَجُلٌ إِلاَّ وَذَقْنُهُ فِي صَدْرِهِ ثُمَّ كَلَّمَهُمْ مُكَلِّمٌ مِنْ نَاحِيَةِ الْبَيْتِ لاَ يَدْرُونَ مَنْ هُوَ أَنِ اغْسِلُوا النَّبِيَّ صلى الله عليه وسلم وَعَلَيْهِ ثِيَابُهُ فَقَامُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَغَسَلُوهُ وَعَلَيْهِ قَمِيصُهُ يَصُبُّونَ الْمَاءَ فَوْقَ الْقَمِيصِ وَيُدَلِّكُونَهُ بِالْقَمِيصِ دُونَ أَيْدِيهِمْ وَكَانَتْ عَائِشَةُ تَقُولُ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا غَسَّلَهُ إِلاَّ نِسَاؤُهُ ‏.‏\hadithno{3141}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: By Allah, we did not know whether we should take off the clothes of the Messenger of Allah (ﷺ) as we took off the clothes of our dead, or wash him while his clothes were on him. When they (the people) differed among themselves, Allah cast slumber over them until every one of them had put his chin on his chest. Then a speaker spoke from a side of the house, and they did not know who he was: Wash the Prophet (ﷺ) while his clothes are on him. So they stood round the Prophet (ﷺ) and washed him while he had his shirt on him. They poured water on his shirt, and rubbed him with his shirt and not with their hands. Aisha used to say: If I had known beforehand about my affair what I found out later, none would have washed him except his wives}}
\hadithdefcmd{abudawud}{3142}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - الْمَعْنَى - عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَتِ ابْنَتُهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ - إِنْ رَأَيْتُنَّ ذَلِكَ - بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَعْطَانَا حَقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏ قَالَ عَنْ مَالِكٍ يَعْنِي إِزَارَهُ وَلَمْ يَقُلْ مُسَدَّدٌ دَخَلَ عَلَيْنَا ‏.‏\hadithno{3142}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1253) Sahih Muslim (939)}\hadithtrans{Narrated Umm 'Atiyyah : The Messenger of Allah (ﷺ) came in when his daughter died, and he said: Wash her with water and lotus leaves three or five times or more than that if you think fit, and put camphor, or some camphor in the last washing, then inform me when you finish. When we had finished we informed him, and he threw us his lower garment saying: Put it next to her body. Malik's version has: that is, his lower garment (izar); and Musaddad did not say: He entered in}}
\hadithdefcmd{abudawud}{3143}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَأَبُو كَامِلٍ - بِمَعْنَى الإِسْنَادِ - أَنَّ يَزِيدَ بْنَ زُرَيْعٍ، حَدَّثَهُمْ حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ حَفْصَةَ، أُخْتِهِ عَنْ أُمِّ عَطِيَّةَ، قَالَتْ مَشَطْنَاهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{3143}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (939)}\hadithtrans{The tradition mentioned above has also been transmitted by Umm 'Atiyyah through a different chain of narrators to the same effect. This version adds:We braided her hair in three plaits}}
\hadithdefcmd{abudawud}{3144}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ وَضَفَّرْنَا رَأْسَهَا ثَلاَثَةَ قُرُونٍ ثُمَّ أَلْقَيْنَاهَا خَلْفَهَا مُقَدَّمَ رَأْسِهَا وَقَرْنَيْهَا ‏.‏\hadithno{3144}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1263) Sahih Muslim (939)}\hadithtrans{The above mentioned has also been transmitted by Umm 'Atiyyah through a different chain of narrators. This version has:we braided her hair in three plaits and placed them behind her back, one plait of the front side and the two side plaits}}
\hadithdefcmd{abudawud}{3145}{حَدَّثَنَا أَبُو كَامِلٍ، وَحَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا خَالِدٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُنَّ فِي غُسْلِ ابْنَتِهِ ‏ "‏ ابْدَأْنَ بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏ ‏.‏\hadithno{3145}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (167) Sahih Muslim (939)}\hadithtrans{Narrated Umm 'Atiyyah :The Messenger of Allah (ﷺ) said to them while washing her daughter: Begin with her right side, and the places where the ablution is performed}}
\hadithdefcmd{abudawud}{3146}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، بِمَعْنَى حَدِيثِ مَالِكٍ زَادَ فِي حَدِيثِ حَفْصَةَ عَنْ أُمِّ عَطِيَّةَ بِنَحْوِ هَذَا وَزَادَتْ فِيهِ ‏ "‏ أَوْ سَبْعًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّهُ ‏"‏ ‏.‏\hadithno{3146}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1253) Sahih Muslim (939)}\hadithtrans{The above mentioned tradition has also been transmitted by Umm 'Atiyyah through a different chain of narrators. This version has:(Wash her) seven times or more if you think fit}}
\hadithdefcmd{abudawud}{3147}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، أَنَّهُ كَانَ يَأْخُذُ الْغُسْلَ عَنْ أُمِّ عَطِيَّةَ، يَغْسِلُ بِالسِّدْرِ مَرَّتَيْنِ وَالثَّالِثَةَ بِالْمَاءِ وَالْكَافُورِ ‏.‏\hadithno{3147}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qatadah:Muhammad b. Sirin used to learn how to wash the dead from Umm 'Atiyyah: he would was with lotus leaves twice and with water and camphor for the third time}}
\hadithdefcmd{abudawud}{3148}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ خَطَبَ يَوْمًا فَذَكَرَ رَجُلاً مِنْ أَصْحَابِهِ قُبِضَ فَكُفِّنَ فِي كَفَنٍ غَيْرِ طَائِلٍ وَقُبِرَ لَيْلاً فَزَجَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُقْبَرَ الرَّجُلُ بِاللَّيْلِ حَتَّى يُصَلَّى عَلَيْهِ إِلاَّ أَنْ يُضْطَرَّ إِنْسَانٌ إِلَى ذَلِكَ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَفَّنَ أَحَدُكُمْ أَخَاهُ فَلْيُحْسِنْ كَفَنَهُ ‏"‏ ‏.‏\hadithno{3148}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (943)}\hadithtrans{Narrated Jabir b. 'Abd Allah :The Prophet (ﷺ) made a speech one day and mentioned a man from among his Companions who died and was shrouded in a shroud of bad quality, and was buried at night. The Prophet (ﷺ) rebuked that man be buried at night until prayer was offered over him, except that a man was forced to do that. The Prophet (ﷺ) said: When one of you shrouds his brother, he should use a shroud of good quality}}
\hadithdefcmd{abudawud}{3149}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا الزُّهْرِيُّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ أُدْرِجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَوْبٍ حِبَرَةٍ ثُمَّ أُخِّرَ عَنْهُ ‏.‏\hadithno{3149}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:That the Messenger of Allah (ﷺ) was shrouded in a garment of Yemeni stuff, it was then removed from him}}
\hadithdefcmd{abudawud}{3150}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عَبْدِ الْكَرِيمِ - حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَقِيلِ بْنِ مَعْقِلٍ، عَنْ أَبِيهِ، عَنْ وَهْبٍ، - يَعْنِي ابْنَ مُنَبِّهٍ - عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا تُوُفِّيَ أَحَدُكُمْ فَوَجَدَ شَيْئًا فَلْيُكَفَّنْ فِي ثَوْبٍ حِبَرَةٍ ‏"‏ ‏.‏\hadithno{3150}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: When one of you dies, and he possesses something, he should be shrouded in the garment of the Yemeni stuff}}
\hadithdefcmd{abudawud}{3151}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، أَخْبَرَتْنِي عَائِشَةُ، قَالَتْ كُفِّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابٍ يَمَانِيَةٍ بِيضٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ ‏.‏\hadithno{3151}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1272) Sahih Muslim (941)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) was shrouded in three garments of white Yemeni stuff, among which was neither a shirt nor a turban}}
\hadithdefcmd{abudawud}{3152}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، مِثْلَهُ زَادَ مِنْ كُرْسُفٍ ‏.‏ قَالَ فَذُكِرَ لِعَائِشَةَ قَوْلُهُمْ فِي ثَوْبَيْنِ وَبُرْدِ حِبَرَةٍ فَقَالَتْ قَدْ أُتِيَ بِالْبُرْدِ وَلَكِنَّهُمْ رَدُّوهُ وَلَمْ يُكَفِّنُوهُ فِيهِ ‏.‏\hadithno{3152}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1271) Sahih Muslim (941)}\hadithtrans{A similar tradition has been transmitted by 'Aishah through a different chain of narrators. This version adds:"of cotton". The narrator said: Aisha was told that the people said that he was shrouded in two garments and one cloak. She replied: A cloak was brought but they returned it and did not shroud him in it}}
\hadithdefcmd{abudawud}{3153}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ يَزِيدَ، - يَعْنِي ابْنَ أَبِي زِيَادٍ - عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُفِّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَلاَثَةِ أَثْوَابٍ نَجْرَانِيَّةٍ الْحُلَّةُ ثَوْبَانِ وَقَمِيصُهُ الَّذِي مَاتَ فِيهِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ عُثْمَانُ فِي ثَلاَثَةِ أَثْوَابٍ حُلَّةٍ حَمْرَاءَ وَقَمِيصِهِ الَّذِي مَاتَ فِيهِ ‏.‏\hadithno{3153}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) was shrouded in three garments made in Najran: two garments and one shirt in which he died. Abu Dawud said: The narrator 'Uthman said: In three garments: two red garments and a shirt in which he died}}
\hadithdefcmd{abudawud}{3154}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، حَدَّثَنَا عَمْرُو بْنُ هَاشِمٍ أَبُو مَالِكٍ الْجَنْبِيُّ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ عَامِرٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ لاَ تَغَالِ لِي فِي كَفَنٍ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَغَالَوْا فِي الْكَفَنِ فَإِنَّهُ يُسْلَبُهُ سَلْبًا سَرِيعًا ‏"‏ ‏.‏\hadithno{3154}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: Do not be extravagant in shrouding, for I heard the Messenger of Allah (ﷺ) say: Do not be extravagant in shrouding, for it will be quickly decayed}}
\hadithdefcmd{abudawud}{3155}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ خَبَّابٍ، قَالَ إِنَّ مُصْعَبَ بْنَ عُمَيْرٍ قُتِلَ يَوْمَ أُحُدٍ وَلَمْ يَكُنْ لَهُ إِلاَّ نَمِرَةٌ كُنَّا إِذَا غَطَّيْنَا بِهَا رَأْسَهُ خَرَجَ رِجْلاَهُ وَإِذَا غَطَّيْنَا رِجْلَيْهِ خَرَجَ رَأْسُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَطُّوا بِهَا رَأْسَهُ وَاجْعَلُوا عَلَى رِجْلَيْهِ شَيْئًا مِنَ الإِذْخِرِ ‏"‏ ‏.‏\hadithno{3155}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3913، 6432) Sahih Muslim (940)}\hadithtrans{Narrated Khabbab:Mus'ab b. 'Umari was killed on the day of Uhud. He had only a striped cloak. When we covered his head with it, his feet appeared, and when we covered his feet, his head appeared. Thereupon the Messenger of Allah (ﷺ) said: Cover his head with it, and cover his feet with some grass}}
\hadithdefcmd{abudawud}{3156}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنِي ابْنُ وَهْبٍ، حَدَّثَنِي هِشَامُ بْنُ سَعْدٍ، عَنْ حَاتِمِ بْنِ أَبِي نَصْرٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ أَبِيهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الْكَفَنِ الْحُلَّةُ وَخَيْرُ الأُضْحِيَةِ الْكَبْشُ الأَقْرَنُ ‏"‏ ‏.‏\hadithno{3156}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubadah ibn as-Samit: The Prophet (ﷺ) said: The best shroud is a lower garment and one which covers the whole body, and the best sacrifice is a horned ram}}
\hadithdefcmd{abudawud}{3157}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي نُوحُ بْنُ حَكِيمٍ الثَّقَفِيُّ، - وَكَانَ قَارِئًا لِلْقُرْآنِ - عَنْ رَجُلٍ، مِنْ بَنِي عُرْوَةَ بْنِ مَسْعُودٍ يُقَالُ لَهُ دَاوُدُ قَدْ وَلَّدَتْهُ أُمُّ حَبِيبَةَ بِنْتُ أَبِي سُفْيَانَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم عَنْ لَيْلَى بِنْتِ قَانِفٍ الثَّقَفِيَّةِ قَالَتْ كُنْتُ فِيمَنْ غَسَّلَ أُمَّ كُلْثُومٍ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم عِنْدَ وَفَاتِهَا فَكَانَ أَوَّلُ مَا أَعْطَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْحِقَاءَ ثُمَّ الدِّرْعَ ثُمَّ الْخِمَارَ ثُمَّ الْمِلْحَفَةَ ثُمَّ أُدْرِجَتْ بَعْدُ فِي الثَّوْبِ الآخِرِ قَالَتْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ عِنْدَ الْبَابِ مَعَهُ كَفَنُهَا يُنَاوِلُنَاهَا ثَوْبًا ثَوْبًا ‏.‏\hadithno{3157}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Layla daughter of Qa'if ath-Thaqafiyyah: I was one of those who washed Umm Kulthum, daughter of the Prophet (ﷺ), when she died. The Messenger of Allah (ﷺ) first gave us lower garment, then shirt, then head-wear, then cloak (which covers the whole body), and then she was shrouded in another garment. She said: The Messenger of Allah (ﷺ) was sitting at the door, and he had shroud with him. He gave us the garments one by one}}
\hadithdefcmd{abudawud}{3158}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْمُسْتَمِرُّ بْنُ الرَّيَّانِ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَطْيَبُ طِيبِكُمُ الْمِسْكُ ‏"‏ ‏.‏\hadithno{3158}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) as saying: The best of your perfumes is musk}}
\hadithdefcmd{abudawud}{3159}{حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ مُطَرِّفٍ الرُّؤَاسِيُّ أَبُو سُفْيَانَ، وَأَحْمَدُ بْنُ جَنَابٍ، قَالاَ حَدَّثَنَا عِيسَى، - قَالَ أَبُو دَاوُدَ هُوَ ابْنُ يُونُسَ - عَنْ سَعِيدِ بْنِ عُثْمَانَ الْبَلَوِيِّ، عَنْ عَزْرَةَ، - وَقَالَ عَبْدُ الرَّحِيمِ عُرْوَةُ بْنُ سَعِيدٍ الأَنْصَارِيُّ - عَنْ أَبِيهِ، عَنِ الْحُصَيْنِ بْنِ وَحْوَحٍ، أَنَّ طَلْحَةَ بْنَ الْبَرَاءِ، مَرِضَ فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ فَقَالَ ‏ "‏ إِنِّي لاَ أَرَى طَلْحَةَ إِلاَّ قَدْ حَدَثَ فِيهِ الْمَوْتُ فَآذِنُونِي بِهِ وَعَجِّلُوا فَإِنَّهُ لاَ يَنْبَغِي لِجِيفَةِ مُسْلِمٍ أَنْ تُحْبَسَ بَيْنَ ظَهْرَانَىْ أَهْلِهِ ‏"‏ ‏.‏\hadithno{3159}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Husayn ibn Wahwah: Talhah ibn al-Bara' fell ill and the Prophet (ﷺ) came to pay him a sick-visit. He said: I think Talhah has died; so tell me (about his death), and make haste, for it is not advisable that the corpse of a Muslim should remain withheld among his family}}
\hadithdefcmd{abudawud}{3160}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا زَكَرِيَّا، حَدَّثَنَا مُصْعَبُ بْنُ شَيْبَةَ، عَنْ طَلْقِ بْنِ حَبِيبٍ الْعَنَزِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا حَدَّثَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَغْتَسِلُ مِنْ أَرْبَعٍ مِنَ الْجَنَابَةِ وَيَوْمَ الْجُمُعَةِ وَمِنَ الْحِجَامَةِ وَغُسْلِ الْمَيِّتِ ‏.‏\hadithno{3160}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) used to take a bath on account of sexual defilement, on Friday, for cupping and washing the dead}}
\hadithdefcmd{abudawud}{3161}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي ابْنُ أَبِي ذِئْبٍ، عَنِ الْقَاسِمِ بْنِ عَبَّاسٍ، عَنْ عَمْرِو بْنِ عُمَيْرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ غَسَّلَ الْمَيِّتَ فَلْيَغْتَسِلْ وَمَنْ حَمَلَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{3161}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Messenger of Allah (ﷺ) said: He who washes the dead should take a bath, and he who carries him should perform ablution}}
\hadithdefcmd{abudawud}{3162}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ إِسْحَاقَ، مَوْلَى زَائِدَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مَنْسُوخٌ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ وَسُئِلَ عَنِ الْغُسْلِ مِنْ غَسْلِ الْمَيِّتِ فَقَالَ يُجْزِيهِ الْوُضُوءُ ‏.‏ قَالَ أَبُو دَاوُدَ أَدْخَلَ أَبُو صَالِحٍ بَيْنَهُ وَبَيْنَ أَبِي هُرَيْرَةَ فِي هَذَا الْحَدِيثِ - يَعْنِي إِسْحَاقَ مَوْلَى زَائِدَةَ - قَالَ وَحَدِيثُ مُصْعَبٍ ضَعِيفٌ فِيهِ خِصَالٌ لَيْسَ الْعَمَلُ عَلَيْهِ ‏.‏\hadithno{3162}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Hurairah through a different chain of narrators to the same effect. Abu Dawud said:This has been abrogated. When Ahmad b. Hanbal was asked about a man taking a bath after his washing the dead, I heard him say: Ablution is sufficient for him. Abu Dawud said: The narrator Abu Salih made a mention of the narrator Ishaq, the client of Za'idah between him and Abu Hurairah. He said: The tradition of Mus'ab is weak. It contains many things that are not practised}}
\hadithdefcmd{abudawud}{3163}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ عُثْمَانَ بْنَ مَظْعُونٍ وَهُوَ مَيِّتٌ حَتَّى رَأَيْتُ الدُّمُوعَ تَسِيلُ ‏.‏\hadithno{3163}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I saw the Messenger of Allah (ﷺ) that he kissed Uthman ibn Maz'un while he was dead, and I saw that tears were flowing (from his eyes)}}
\hadithdefcmd{abudawud}{3164}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، - أَوْ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، - قَالَ رَأَى نَاسٌ نَارًا فِي الْمَقْبَرَةِ فَأَتَوْهَا فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْقَبْرِ وَإِذَا هُوَ يَقُولُ ‏ "‏ نَاوِلُونِي صَاحِبَكُمْ ‏"‏ ‏.‏ فَإِذَا هُوَ الرَّجُلُ الَّذِي كَانَ يَرْفَعُ صَوْتَهُ بِالذِّكْرِ ‏.‏\hadithno{3164}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The people saw fire (light) in the graveyard and they went there. They found that the Messenger of Allah (ﷺ) was in a grave and he was saying: Give me your companion. This was a man who used to raise his voice while mentioning the name of Allah}}
\hadithdefcmd{abudawud}{3165}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ نُبَيْحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا حَمَلْنَا الْقَتْلَى يَوْمَ أُحُدٍ لِنَدْفِنَهُمْ فَجَاءَ مُنَادِي النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكُمْ أَنْ تَدْفِنُوا الْقَتْلَى فِي مَضَاجِعِهِمْ فَرَدَدْنَاهُمْ ‏.‏\hadithno{3165}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: On the day of Uhud we brought the martyrs to bury them (at another place), but the crier of the Prophet (ﷺ) came and said: The Messenger of Allah (ﷺ) has commanded you to bury the martyrs at the place where they fell. So we took them back}}
\hadithdefcmd{abudawud}{3166}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدٍ الْيَزَنِيِّ، عَنْ مَالِكِ بْنِ هُبَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يَمُوتُ فَيُصَلِّي عَلَيْهِ ثَلاَثَةُ صُفُوفٍ مِنَ الْمُسْلِمِينَ إِلاَّ أَوْجَبَ ‏"‏ ‏.‏ قَالَ فَكَانَ مَالِكٌ إِذَا اسْتَقَلَّ أَهْلَ الْجَنَازَةِ جَزَّأَهُمْ ثَلاَثَةَ صُفُوفٍ لِلْحَدِيثِ ‏.‏\hadithno{3166}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Malik ibn Hubayrah: The Prophet (ﷺ) said: If any Muslim dies and three rows of Muslims pray over him, it will assure him (of Paradise). When Malik considered those who accompanied a bier to be a few, he divided them into three rows in accordance with this tradition}}
\hadithdefcmd{abudawud}{3167}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ نُهِينَا أَنْ نَتَّبِعَ، الْجَنَائِزَ وَلَمْ يُعْزَمْ عَلَيْنَا ‏.‏\hadithno{3167}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (313) Sahih Muslim (938 After  1491)}\hadithtrans{Narrated Umm 'Atiyyah :We were forbidden accompany the biers, but it was not stressed upon us}}
\hadithdefcmd{abudawud}{3168}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، يَرْوِيهِ قَالَ مَنْ تَبِعَ جَنَازَةً فَصَلَّى عَلَيْهَا فَلَهُ قِيرَاطٌ وَمَنْ تَبِعَهَا حَتَّى يُفْرَغَ مِنْهَا فَلَهُ قِيرَاطَانِ أَصْغَرُهُمَا مِثْلُ أُحُدٍ أَوْ أَحَدُهُمَا مِثْلُ أُحُدٍ ‏.‏\hadithno{3168}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:If anyone attends the funeral and prays over (the dead), he will get the reward of one qirat, and if anyone attends the funeral until the completion (of the burial), he will get the reward of two qirats, the smaller of them being equivalent of Uhud, or one of them being equivalent to Uhud}}
\hadithdefcmd{abudawud}{3169}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَعَبْدُ الرَّحْمَنِ بْنُ حُسَيْنٍ الْهَرَوِيُّ، قَالاَ حَدَّثَنَا الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، حَدَّثَنِي أَبُو صَخْرٍ، - وَهُوَ حُمَيْدُ بْنُ زِيَادٍ - أَنَّ يَزِيدَ بْنَ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، حَدَّثَهُ أَنَّ دَاوُدَ بْنَ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ حَدَّثَهُ عَنْ أَبِيهِ، أَنَّهُ كَانَ عِنْدَ ابْنِ عُمَرَ بْنِ الْخَطَّابِ إِذْ طَلَعَ خَبَّابٌ صَاحِبُ الْمَقْصُورَةِ فَقَالَ يَا عَبْدَ اللَّهِ بْنَ عُمَرَ أَلاَ تَسْمَعُ مَا يَقُولُ أَبُو هُرَيْرَةَ إِنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ خَرَجَ مَعَ جَنَازَةٍ مِنْ بَيْتِهَا وَصَلَّى عَلَيْهَا ‏"‏ ‏.‏ فَذَكَرَ مَعْنَى حَدِيثِ سُفْيَانَ فَأَرْسَلَ ابْنُ عُمَرَ إِلَى عَائِشَةَ فَقَالَتْ صَدَقَ أَبُو هُرَيْرَةَ ‏.‏\hadithno{3169}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (945)}\hadithtrans{Dawud b. 'Amir b. Sa'd b. Abi Waqqas said that his father 'Amir b. Sa'd was with Ibn 'Umar b. al-Khattab when Khabbab, the owner of the closet (maqsurah), came and said:'Abd Allah b.'Umar dont you hear what Abu Hurairah says ? He heard the Messenger of Allah (ﷺ) say: If anyone goes out of his house, accompanies bier and prays over it.... He then mentioned the rest of the tradition as narrated by Sufyan. Thereupon Ibn 'Umar sent someone to 'Aishah (asking her about it). She replied: Abu Hurairah spoke the truth}}
\hadithdefcmd{abudawud}{3170}{حَدَّثَنَا الْوَلِيدُ بْنُ شُجَاعٍ السَّكُونِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أَبُو صَخْرٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ مُسْلِمٍ يَمُوتُ فَيَقُومُ عَلَى جَنَازَتِهِ أَرْبَعُونَ رَجُلاً لاَ يُشْرِكُونَ بِاللَّهِ شَيْئًا إِلاَّ شُفِّعُوا فِيهِ ‏"‏ ‏.‏\hadithno{3170}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (948)}\hadithtrans{Narrated Ibn 'Abbas:I heard the Prophet (ﷺ) say: If any Muslim dies and forty men associate nothing with Allah stand over his bier. Allah will accept them as intercessors for him}}
\hadithdefcmd{abudawud}{3171}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، قَالاَ حَدَّثَنَا حَرْبٌ، - يَعْنِي ابْنَ شَدَّادٍ - حَدَّثَنَا يَحْيَى، حَدَّثَنِي بَابُ بْنُ عُمَيْرٍ، حَدَّثَنِي رَجُلٌ، مِنْ أَهْلِ الْمَدِينَةِ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُتْبَعُ الْجَنَازَةُ بِصَوْتٍ وَلاَ نَارٍ ‏"‏ ‏.‏ زَادَ هَارُونُ ‏"‏ وَلاَ يُمْشَى بَيْنَ يَدَيْهَا ‏"‏ ‏.‏\hadithno{3171}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: The Prophet (said) said: A bier should not be followed by a loud voice (of wailing) or fire. Abu Dawud said: Harun (one of the narrators) added: "And it should not be preceded (with those) either}}
\hadithdefcmd{abudawud}{3172}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْجَنَازَةَ فَقُومُوا لَهَا حَتَّى تُخَلِّفَكُمْ أَوْ تُوضَعَ ‏"‏ ‏.‏\hadithno{3172}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1307) Sahih Muslim (958)}\hadithtrans{Narrated 'Amir b. Rabi'ah:The Prophet (ﷺ) as saying: When you see a funeral, stand up for it till it leaves you behind or it is placed (on the ground)}}
\hadithdefcmd{abudawud}{3173}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنِ ابْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَبِعْتُمُ الْجَنَازَةَ فَلاَ تَجْلِسُوا حَتَّى تُوضَعَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ الثَّوْرِيُّ عَنْ سُهَيْلٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ قَالَ فِيهِ حَتَّى تُوضَعَ بِالأَرْضِ وَرَوَاهُ أَبُو مُعَاوِيَةَ عَنْ سُهَيْلٍ قَالَ حَتَّى تُوضَعَ فِي اللَّحْدِ ‏.‏ قَالَ أَبُو دَاوُدَ وَسُفْيَانُ أَحْفَظُ مِنْ أَبِي مُعَاوِيَةَ ‏.‏\hadithno{3173}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) as saying: When you follow a funeral, do not sit until the bier is placed (on the ground). Abu Dawud said: This tradition has been narrated by al-Thawri (i.e. Sufyan) from Suhail, from his father on the authority of Abu Hurairah. This version has: until it (the bier) is placed on the ground. It has also been narrated by Abu Mu'wiyah from Suhail. This has: Until it is placed in the grave. Abu Dawud said: Sufyan's version is more guarded than that of Abu Mu'awiyah}}
\hadithdefcmd{abudawud}{3174}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ الْحَرَّانِيُّ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا أَبُو عَمْرٍو، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، حَدَّثَنِي جَابِرٌ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ مَرَّتْ بِنَا جَنَازَةٌ فَقَامَ لَهَا فَلَمَّا ذَهَبْنَا لِنَحْمِلَ إِذَا هِيَ جَنَازَةُ يَهُودِيٍّ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّمَا هِيَ جَنَازَةُ يَهُودِيٍّ ‏.‏ فَقَالَ ‏ "‏ إِنَّ الْمَوْتَ فَزَعٌ فَإِذَا رَأَيْتُمْ جَنَازَةً فَقُومُوا ‏"‏ ‏.‏\hadithno{3174}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1311) Sahih Muslim (960)}\hadithtrans{Narrated Jabir:We were with the Prophet (ﷺ) when a funeral passed hi and he stood up for it. When we went to carry it, we found that it was a funeral of a Jew. We, therefore said: Messenger of Allah, this is the funeral of a Jew. He said: Death is fearful event, so when you see a funeral, stand up}}
\hadithdefcmd{abudawud}{3175}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ وَاقِدِ بْنِ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ الأَنْصَارِيِّ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ مَسْعُودِ بْنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ فِي الْجَنَائِزِ ثُمَّ قَعَدَ بَعْدُ ‏.‏\hadithno{3175}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (962)}\hadithtrans{Narrated 'Ali bin Abi Talib:The Prophet (ﷺ) stood up for a funeral (to show respect) and thereafter he sat down}}
\hadithdefcmd{abudawud}{3176}{حَدَّثَنَا هِشَامُ بْنُ بَهْرَامَ الْمَدَائِنِيُّ، أَخْبَرَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو الأَسْبَاطِ الْحَارِثِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ بْنِ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُومُ فِي الْجَنَازَةِ حَتَّى تُوضَعَ فِي اللَّحْدِ فَمَرَّ بِهِ حَبْرٌ مِنَ الْيَهُودِ فَقَالَ هَكَذَا نَفْعَلُ ‏.‏ فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏ "‏ اجْلِسُوا خَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{3176}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubadah ibn as-Samit: The Messenger of Allah (ﷺ) used to stand up for a funeral until the corpse was placed in the grave. A learned Jew (once) passed him and said: This is how we do. The Prophet (ﷺ) sat down and said: Sit down and act differently from them}}
\hadithdefcmd{abudawud}{3177}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ ثَوْبَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِدَابَّةٍ وَهُوَ مَعَ الْجَنَازَةِ فَأَبَى أَنْ يَرْكَبَهَا فَلَمَّا انْصَرَفَ أُتِيَ بِدَابَّةٍ فَرَكِبَ فَقِيلَ لَهُ فَقَالَ ‏ "‏ إِنَّ الْمَلاَئِكَةَ كَانَتْ تَمْشِي فَلَمْ أَكُنْ لأَرْكَبَ وَهُمْ يَمْشُونَ فَلَمَّا ذَهَبُوا رَكِبْتُ ‏"‏ ‏.‏\hadithno{3177}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Thawban: An animal was brought to the Messenger of Allah (ﷺ) while he was going with a funeral. He refused to ride on it. When the funeral was away, the animal was brought to him and he rode on it. He was asked about it. He said: The angels were on their feet. I was not to ride while they were walking. When they went away, I rode}}
\hadithdefcmd{abudawud}{3178}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، سَمِعَ جَابِرَ بْنَ سَمُرَةَ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم عَلَى ابْنِ الدَّحْدَاحِ وَنَحْنُ شُهُودٌ ثُمَّ أُتِيَ بِفَرَسٍ فَعُقِلَ حَتَّى رَكِبَهُ فَجَعَلَ يَتَوَقَّصُ بِهِ وَنَحْنُ نَسْعَى حَوْلَهُ ‏.‏\hadithno{3178}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (965)}\hadithtrans{Narrated Jabir b. Samurah:The Prophet (ﷺ) offered funeral prayer over Ibn al-Dahdah while we were present. He was then brought a horse, and it was tied until he rode it. It then began to gallop and we were running around it}}
\hadithdefcmd{abudawud}{3179}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ يَمْشُونَ أَمَامَ الْجَنَازَةِ ‏.‏\hadithno{3179}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Salim reported on the authority of his father:I saw the Prophet (ﷺ) and Abu Bakr and Umar walking before the funeral}}
\hadithdefcmd{abudawud}{3180}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ يُونُسَ، عَنْ زِيَادِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، - وَأَحْسَبُ أَنَّ أَهْلَ، زِيَادٍ أَخْبَرُونِي أَنَّهُ، رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم - قَالَ ‏ "‏ الرَّاكِبُ يَسِيرُ خَلْفَ الْجَنَازَةِ وَالْمَاشِي يَمْشِي خَلْفَهَا وَأَمَامَهَا وَعَنْ يَمِينِهَا وَعَنْ يَسَارِهَا قَرِيبًا مِنْهَا وَالسِّقْطُ يُصَلَّى عَلَيْهِ وَيُدْعَى لِوَالِدَيْهِ بِالْمَغْفِرَةِ وَالرَّحْمَةِ ‏"‏ ‏.‏\hadithno{3180}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Mughirah ibn Shu'bah: (I think that the people of Ziyad informed me that he reported on the authority of the Prophet (ﷺ): A rider should go behind the bier, and those on foot should walk behind it, in front of it, on its right and on its left keeping near it. Prayer should be offered over an abortion and forgiveness and mercy supplicated for its parents}}
\hadithdefcmd{abudawud}{3181}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْرِعُوا بِالْجَنَازَةِ فَإِنْ تَكُ صَالِحَةً فَخَيْرٌ تُقَدِّمُونَهَا إِلَيْهِ وَإِنْ تَكُ سِوَى ذَلِكَ فَشَرٌّ تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏\hadithno{3181}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1315) Sahih Muslim (944)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: Walk quickly with a funeral, for if the dead person was good it is a good condition to which you are sending him on, but it he was otherwise it is an evil of which you are riding yourselves}}
\hadithdefcmd{abudawud}{3182}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ عُيَيْنَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ فِي جَنَازَةِ عُثْمَانَ بْنِ أَبِي الْعَاصِ وَكُنَّا نَمْشِي مَشْيًا خَفِيفًا فَلَحِقَنَا أَبُو بَكْرَةَ فَرَفَعَ سَوْطَهُ فَقَالَ لَقَدْ رَأَيْتُنَا وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَرْمُلُ رَمَلاً ‏.‏\hadithno{3182}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uyaynah ibn AbdurRahman reported on the authority of his father that he attended the funeral of Uthman ibn Abul'As. He said:We were walking slowly. AbuBakrah then joined us and he raised his flog at us and said: You have seen us when we were with the Messenger of Allah (ﷺ). We were walking quickly}}
\hadithdefcmd{abudawud}{3183}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنْ عُيَيْنَةَ، بِهَذَا الْحَدِيثِ قَالاَ فِي جَنَازَةِ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ وَقَالَ فَحَمَلَ عَلَيْهِمْ بَغْلَتَهُ وَأَهْوَى بِالسَّوْطِ ‏.‏\hadithno{3183}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uyaynah also reported the aforementioned tradition (No. 3176) through a different chain of transmitters. This version goes:We attended the funeral of AbdurRahman ibn Samurah and he said: He (AbuBakrah) made his mule run quickly and pointed with the flog}}
\hadithdefcmd{abudawud}{3184}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ يَحْيَى الْمُجَبِّرِ، - قَالَ أَبُو دَاوُدَ وَهُوَ يَحْيَى بْنُ عَبْدِ اللَّهِ التَّيْمِيُّ - عَنْ أَبِي مَاجِدَةَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ سَأَلْنَا نَبِيَّنَا صلى الله عليه وسلم عَنِ الْمَشْىِ مَعَ الْجَنَازَةِ فَقَالَ ‏ "‏ مَا دُونَ الْخَبَبِ إِنْ يَكُنْ خَيْرًا تَعَجَّلْ إِلَيْهِ وَإِنْ يَكُنْ غَيْرَ ذَلِكَ فَبُعْدًا لأَهْلِ النَّارِ وَالْجَنَازَةُ مَتْبُوعَةٌ وَلاَ تُتْبَعُ لَيْسَ مَعَهَا مَنْ تَقَدَّمَهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ ضَعِيفٌ هُوَ يَحْيَى بْنُ عَبْدِ اللَّهِ وَهُوَ يَحْيَى الْجَابِرُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا كُوفِيٌّ وَأَبُو مَاجِدَةَ بَصْرِيٌّ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو مَاجِدَةَ هَذَا لاَ يُعْرَفُ ‏.‏\hadithno{3184}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: We asked the Prophet (ﷺ) about walking with the funeral. He replied: Not running (but walking quickly). If he (the dead person) was good, send him to it quickly; if he was otherwise, keep away the people of Hell. The bier should be followed and should not follow. Those who go in front of it are not accompanying it. Abu Dawud said: The narrator Yahya b. 'Abd Allah is weak. He is Yahya al-Jabir Abu Dawud said: This is from Kufah, and Abu Majidah is from Basrah. Abu Dawud said: Abu Majidah is obscure}}
\hadithdefcmd{abudawud}{3185}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكٌ، حَدَّثَنِي جَابِرُ بْنُ سَمُرَةَ، قَالَ مَرِضَ رَجُلٌ فَصِيحَ عَلَيْهِ فَجَاءَ جَارُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ إِنَّهُ قَدْ مَاتَ ‏.‏ قَالَ ‏"‏ وَمَا يُدْرِيكَ ‏"‏ ‏.‏ قَالَ أَنَا رَأَيْتُهُ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَمْ يَمُتْ ‏"‏ ‏.‏ قَالَ فَرَجَعَ فَصِيحَ عَلَيْهِ فَجَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّهُ قَدْ مَاتَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَمْ يَمُتْ ‏"‏ ‏.‏ فَرَجَعَ فَصِيحَ عَلَيْهِ فَقَالَتِ امْرَأَتُهُ انْطَلِقْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبِرْهُ ‏.‏ فَقَالَ الرَّجُلُ اللَّهُمَّ الْعَنْهُ ‏.‏ قَالَ ثُمَّ انْطَلَقَ الرَّجُلُ فَرَآهُ قَدْ نَحَرَ نَفْسَهُ بِمِشْقَصٍ مَعَهُ فَانْطَلَقَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ أَنَّهُ قَدْ مَاتَ فَقَالَ ‏"‏ مَا يُدْرِيكَ ‏"‏ ‏.‏ قَالَ رَأَيْتُهُ يَنْحَرُ نَفْسَهُ بِمَشَاقِصَ مَعَهُ ‏.‏ قَالَ ‏"‏ أَنْتَ رَأَيْتَهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ إِذًا لاَ أُصَلِّي عَلَيْهِ ‏"‏ ‏.‏\hadithno{3185}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (978)}\hadithtrans{Narrated Jabir ibn Samurah: A man fell ill and a cry was raised (for his death). So his neighbour came to the Messenger of Allah (ﷺ) and said to him: He has died. He asked: Who told you? He said: I have seen him. The Messenger of Allah (ﷺ) said: He has not died. He then returned. A cry was again raised (for his death). He came to the Messenger of Allah (ﷺ) and said: He has died. The Prophet (ﷺ) said: He has not died. He then returned. A cry was again raised over him. His wife said: Go to the Messenger of Allah (ﷺ) and inform him. The man said: O Allah, curse him. He said: The man then went and saw that he had killed himself with an arrowhead. So he went to the Prophet (ﷺ) and informed him that he had died. He asked: Who told you? He replied: I myself saw that he had killed himself with arrowheads. He asked: Have you seen him? He replied: Yes. He then said: Then I shall not pray over him}}
\hadithdefcmd{abudawud}{3186}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، حَدَّثَنِي نَفَرٌ، مِنْ أَهْلِ الْبَصْرَةِ عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يُصَلِّ عَلَى مَاعِزِ بْنِ مَالِكٍ وَلَمْ يَنْهَ عَنِ الصَّلاَةِ عَلَيْهِ ‏.‏\hadithno{3186}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBarzah al-Aslami: The Messenger of Allah (ﷺ) did not pray over Ma'iz ibn Malik, and he did not prohibit to pray over him}}
\hadithdefcmd{abudawud}{3187}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ مَاتَ إِبْرَاهِيمُ ابْنُ النَّبِيِّ صلى الله عليه وسلم وَهُوَ ابْنُ ثَمَانِيَةَ عَشَرَ شَهْرًا فَلَمْ يُصَلِّ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3187}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Ibrahim, the son of the Prophet (ﷺ), died when he was eighteen months old. The Messenger of Allah (ﷺ) did not pray over him}}
\hadithdefcmd{abudawud}{3188}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ وَائِلِ بْنِ دَاوُدَ، قَالَ سَمِعْتُ الْبَهِيَّ، قَالَ لَمَّا مَاتَ إِبْرَاهِيمُ ابْنُ النَّبِيِّ صلى الله عليه وسلم صَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَقَاعِدِ ‏.‏ قَالَ أَبُو دَاوُدَ قَرَأْتُ عَلَى سَعِيدِ بْنِ يَعْقُوبَ الطَّالْقَانِيِّ قِيلَ لَهُ حَدَّثَكُمُ ابْنُ الْمُبَارَكِ عَنْ يَعْقُوبَ بْنِ الْقَعْقَاعِ عَنْ عَطَاءٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى ابْنِهِ إِبْرَاهِيمَ وَهُوَ ابْنُ سَبْعِينَ لَيْلَةً ‏.‏\hadithno{3188}\hadithgrade{Al-Albani: Daif Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Daif Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bahiyy: When Ibrahim, the son of the Prophet (ﷺ) died, he prayed over him at the place where he used to sit. Abu Dawud said: I recited to Sa'id b. Ya'qub al-Taliqani saying: Ibn al-Mubarak transmitted to you from Ya'qub b. al-Qa'qa' on the authority of 'Ata that the Prophet (ﷺ) prayed over his son Ibrahim when he was seventeen days old}}
\hadithdefcmd{abudawud}{3189}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ صَالِحِ بْنِ عَجْلاَنَ، وَمُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّادٍ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ وَاللَّهِ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ الْبَيْضَاءِ إِلاَّ فِي الْمَسْجِدِ ‏.‏\hadithno{3189}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (973)}\hadithtrans{Narrated 'Aishah:I swear by Allah, the Messenger of Allah (ﷺ) prayed over Suhail b. al-Baida' in the mosque}}
\hadithdefcmd{abudawud}{3190}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ، - يَعْنِي ابْنَ عُثْمَانَ - عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ وَاللَّهِ لَقَدْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى ابْنَىْ بَيْضَاءَ فِي الْمَسْجِدِ سُهَيْلٍ وَأَخِيهِ ‏.‏\hadithno{3190}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (973)}\hadithtrans{Narrated 'Aishah:I swear by Allah, the Messenger of Allah (ﷺ) prayed in the mosque over the two sons of al-Baida': Suhail and his brother}}
\hadithdefcmd{abudawud}{3191}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي ذِئْبٍ، حَدَّثَنِي صَالِحٌ، مَوْلَى التَّوْأَمَةِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى عَلَى جَنَازَةٍ فِي الْمَسْجِدِ فَلاَ شَىْءَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3191}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone prays over the dead in the mosque, there is nothing on him}}
\hadithdefcmd{abudawud}{3192}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مُوسَى بْنُ عُلَىِّ بْنِ رَبَاحٍ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ، قَالَ ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ أَوْ نَقْبُرَ فِيهِنَّ مَوْتَانَا حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً حَتَّى تَرْتَفِعَ وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَمِيلَ وَحِينَ تَضَيَّفُ الشَّمْسُ لِلْغُرُوبِ حَتَّى تَغْرُبَ أَوْ كَمَا قَالَ ‏.‏\hadithno{3192}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (831)}\hadithtrans{Narrated 'Uqbah bin 'Amir:There were three times at which the Messenger of Allah (ﷺ) used to forbid us to pray or bury our dead - when the sun begins to rise till it is fully up, when the sun is at its height midway till it passes the meridian, and when the sun draws near to setting till it sets, or as he said}}
\hadithdefcmd{abudawud}{3193}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ يَحْيَى بْنِ صُبَيْحٍ، حَدَّثَنِي عَمَّارٌ، مَوْلَى الْحَارِثِ بْنِ نَوْفَلٍ أَنَّهُ شَهِدَ جَنَازَةَ أُمِّ كُلْثُومٍ وَابْنِهَا فَجُعِلَ الْغُلاَمُ مِمَّا يَلِي الإِمَامَ فَأَنْكَرْتُ ذَلِكَ وَفِي الْقَوْمِ ابْنُ عَبَّاسٍ وَأَبُو سَعِيدٍ الْخُدْرِيُّ وَأَبُو قَتَادَةَ وَأَبُو هُرَيْرَةَ فَقَالُوا هَذِهِ السُّنَّةُ ‏.‏\hadithno{3193}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yahya ibn Subayh said:Ammar client of al-Harith ibn Nawfal told me that he attended the funeral of Umm Kulthum, and her son. The body of the boy was placed near the imam. I objected to it. Among the people there were Ibn Abbas, AbuSa'id al-Khudri, AbuQatadah and AbuHurayrah. They said: This is the sunnah (established practice of the Prophet)}}
\hadithdefcmd{abudawud}{3194}{حَدَّثَنَا دَاوُدُ بْنُ مُعَاذٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ نَافِعٍ أَبِي غَالِبٍ، قَالَ كُنْتُ فِي سِكَّةِ الْمِرْبَدِ فَمَرَّتْ جَنَازَةٌ مَعَهَا نَاسٌ كَثِيرٌ قَالُوا جَنَازَةُ عَبْدِ اللَّهِ بْنِ عُمَيْرٍ فَتَبِعْتُهَا فَإِذَا أَنَا بِرَجُلٍ عَلَيْهِ كِسَاءٌ رَقِيقٌ عَلَى بُرَيْذِينَتِهِ وَعَلَى رَأْسِهِ خِرْقَةٌ تَقِيهِ مِنَ الشَّمْسِ فَقُلْتُ مَنْ هَذَا الدِّهْقَانُ قَالُوا هَذَا أَنَسُ بْنُ مَالِكٍ ‏.‏ فَلَمَّا وُضِعَتِ الْجَنَازَةُ قَامَ أَنَسٌ فَصَلَّى عَلَيْهَا وَأَنَا خَلْفَهُ لاَ يَحُولُ بَيْنِي وَبَيْنَهُ شَىْءٌ فَقَامَ عِنْدَ رَأْسِهِ فَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ لَمْ يُطِلْ وَلَمْ يُسْرِعْ ثُمَّ ذَهَبَ يَقْعُدُ فَقَالُوا يَا أَبَا حَمْزَةَ الْمَرْأَةُ الأَنْصَارِيَّةُ فَقَرَّبُوهَا وَعَلَيْهَا نَعْشٌ أَخْضَرُ فَقَامَ عِنْدَ عَجِيزَتِهَا فَصَلَّى عَلَيْهَا نَحْوَ صَلاَتِهِ عَلَى الرَّجُلِ ثُمَّ جَلَسَ فَقَالَ الْعَلاَءُ بْنُ زِيَادٍ يَا أَبَا حَمْزَةَ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى الْجَنَازَةِ كَصَلاَتِكَ يُكَبِّرُ عَلَيْهَا أَرْبَعًا وَيَقُومُ عِنْدَ رَأْسِ الرَّجُلِ وَعَجِيزَةِ الْمَرْأَةِ قَالَ نَعَمْ ‏.‏ قَالَ يَا أَبَا حَمْزَةَ غَزَوْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ غَزَوْتُ مَعَهُ حُنَيْنًا فَخَرَجَ الْمُشْرِكُونَ فَحَمَلُوا عَلَيْنَا حَتَّى رَأَيْنَا خَيْلَنَا وَرَاءَ ظُهُورِنَا وَفِي الْقَوْمِ رَجُلٌ يَحْمِلُ عَلَيْنَا فَيَدُقُّنَا وَيَحْطِمُنَا فَهَزَمَهُمُ اللَّهُ وَجَعَلَ يُجَاءُ بِهِمْ فَيُبَايِعُونَهُ عَلَى الإِسْلاَمِ فَقَالَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِنَّ عَلَىَّ نَذْرًا إِنْ جَاءَ اللَّهُ بِالرَّجُلِ الَّذِي كَانَ مُنْذُ الْيَوْمِ يَحْطِمُنَا لأَضْرِبَنَّ عُنُقَهُ ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجِيءَ بِالرَّجُلِ فَلَمَّا رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَا رَسُولَ اللَّهِ تُبْتُ إِلَى اللَّهِ ‏.‏ فَأَمْسَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُبَايِعُهُ لِيَفِيَ الآخَرُ بِنَذْرِهِ ‏.‏ قَالَ فَجَعَلَ الرَّجُلُ يَتَصَدَّى لِرَسُولِ اللَّهِ صلى الله عليه وسلم لِيَأْمُرَهُ بِقَتْلِهِ وَجَعَلَ يَهَابُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَقْتُلَهُ فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهُ لاَ يَصْنَعُ شَيْئًا بَايَعَهُ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ نَذْرِي ‏.‏ فَقَالَ ‏"‏ إِنِّي لَمْ أُمْسِكْ عَنْهُ مُنْذُ الْيَوْمِ إِلاَّ لِتُوفِيَ بِنَذْرِكَ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَلاَ أَوْمَضْتَ إِلَىَّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيْسَ لِنَبِيٍّ أَنْ يُومِضَ ‏"‏ ‏.‏ قَالَ أَبُو غَالِبٍ فَسَأَلْتُ عَنْ صَنِيعِ أَنَسٍ فِي قِيَامِهِ عَلَى الْمَرْأَةِ عِنْدَ عَجِيزَتِهَا فَحَدَّثُونِي أَنَّهُ إِنَّمَا كَانَ لأَنَّهُ لَمْ تَكُنِ النُّعُوشُ فَكَانَ الإِمَامُ يَقُومُ حِيَالَ عَجِيزَتِهَا يَسْتُرُهَا مِنَ الْقَوْمِ ‏.‏ قَالَ أَبُو دَاوُدَ قَوْلُ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ نَسَخَ مِنْ هَذَا الْحَدِيثِ الْوَفَاءَ بِالنَّذْرِ فِي قَتْلِهِ بِقَوْلِهِ إِنِّي قَدْ تُبْتُ ‏.‏\hadithno{3194}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Nafi' AbuGhalib said:I was in the Sikkat al-Mirbad. A bier passed and a large number of people were accompanying it. They said: Bier of Abdullah ibn Umayr. So I followed it. Suddenly I saw a man, who had a thin garment on riding his small mule. He had a piece of cloth on his head to protect himself from the sun. I asked: Who is this important man? People said: This is Anas ibn Malik. When the bier was placed, Anas stood and led the funeral prayer over him while I was just behind him, and there was no obstruction between me and him. He stood near his head, and uttered four takbirs (Allah is Most Great). He neither lengthened the prayer nor hurried it. He then went to sit down. They said: AbuHamzah, (here is the bier of) an Ansari woman. They brought her near him and there was a green cupola-shaped structure over her bier. He stood opposite her hips and led the funeral prayer over her as he had led it over the man. He then sat down. Al-Ala' ibn Ziyad asked: AbuHamzah, did the Messenger of Allah (ﷺ) say the funeral prayer over the dead as you have done, uttering four takbirs (Allah is Most Great) over her, and standing opposite the head of a man and the hips of a woman? He replied: Yes. He asked: AbuHamzah, did you fight with the Messenger of Allah? He replied: Yes. I fought with him in the battle of Hunayn. The polytheists came out and invaded us so severely that we saw our horses behind our backs. Among the people (i.e. the unbelievers) there was a man who was attacking us, and striking and wounding us (with his sword). Allah then defeated them. They were then brought and began to take the oath of allegiance to him for Islam. A man from among the companions of the Prophet (ﷺ) said: I make a vow to myself that if Allah brings the man who was striking us (with his sword) that day, I shall behead him. The Messenger of Allah (ﷺ) kept silent and the man was brought (as a captive). When he saw the Messenger of Allah (ﷺ), he said: Messenger of Allah, I have repented to Allah. The Messenger of Allah (ﷺ) stopped (for a while) receiving his oath of allegiance, so that the other man might fulfil his vow. But the man began to wait for the order of the Messenger of Allah (ﷺ) for his murder. He was afraid of the Messenger of Allah (ﷺ) to kill him. When the Messenger of Allah (ﷺ) saw that he did not do anything, he received his oath of allegiance. The man said: Messenger of Allah, what about my vow? He said: I stopped (receiving his oath of allegiance) today so that you might fulfil your vow. He said: Messenger of Allah, why did you not give any signal to me? The Prophet (ﷺ) said: It is not worthy of a Prophet to give a signal. AbuGhalib said: I asked (the people) about Anas standing opposite the hips of a woman. They told me that this practice was due to the fact that (in the days of the Prophet) there were no cupola-shaped structures over the biers of women. So the imam used to stand opposite the hips of a woman to hide her from the people. Abu Dawud said: The saying of the Prophet (ﷺ) "I have been commanded to fight against the people until they say: There is no god bu Allah" abrogated this tradition of fulfilling the vow by his remark: "I have repented}}
\hadithdefcmd{abudawud}{3195}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ صَلَّيْتُ وَرَاءَ النَّبِيِّ صلى الله عليه وسلم عَلَى امْرَأَةٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ عَلَيْهَا لِلصَّلاَةِ وَسَطَهَا ‏.‏\hadithno{3195}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1331) Sahih Muslim (964)}\hadithtrans{Narrated Samurah bin Jundab:I prayed behing the Prophet (ﷺ) over a woman who died in childbirth, and he stood opposite her waist}}
\hadithdefcmd{abudawud}{3196}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَخْبَرَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، عَنِ الشَّعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِقَبْرٍ رَطْبٍ فَصَفُّوا عَلَيْهِ وَكَبَّرَ عَلَيْهِ أَرْبَعًا ‏.‏ فَقُلْتُ لِلشَّعْبِيِّ مَنْ حَدَّثَكَ قَالَ الثِّقَةُ مَنْ شَهِدَهُ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ‏.‏\hadithno{3196}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1247) Sahih Muslim (954)}\hadithtrans{Narrated Al-Sha'bi:The Messenger of Allah (ﷺ) passed a grave dug freshly. They arranged a row and uttered four takbirs over it. I asked al-Sha'bi: Who told you ? He replied: A reliable person whom 'Abd Allah b. 'Abbas attended}}
\hadithdefcmd{abudawud}{3197}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ كَانَ زَيْدٌ - يَعْنِي ابْنَ أَرْقَمَ - يُكَبِّرُ عَلَى جَنَائِزِنَا أَرْبَعًا وَإِنَّهُ كَبَّرَ عَلَى جَنَازَةٍ خَمْسًا فَسَأَلْتُهُ فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُهَا ‏.‏ قَالَ أَبُو دَاوُدَ وَأَنَا لِحَدِيثِ ابْنِ الْمُثَنَّى أَتْقَنُ ‏.‏\hadithno{3197}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (957)}\hadithtrans{Narrated Ibn Abi Laila: Zaid b. Arqam used to utter four takbirs (Allah is Most Great) over our dead person (during prayer). He uttered five takbirs on a dead person. So I asked him. He replied: The Messenger of Allah (ﷺ) used to utter those. Abu Dawud said: I remember the tradition of Ibn al-Muthanna in a more guarded way}}
\hadithdefcmd{abudawud}{3198}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، قَالَ صَلَّيْتُ مَعَ ابْنِ عَبَّاسٍ عَلَى جَنَازَةٍ فَقَرَأَ بِفَاتِحَةِ الْكِتَابِ فَقَالَ إِنَّهَا مِنَ السُّنَّةِ ‏.‏\hadithno{3198}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1335)}\hadithtrans{Narrated Talhah b. 'Abd Allah b. 'Awf:I prayed over a dead person along with Ibn 'Abbas. He recited Surat al-Fatihah and he said: This is the Sunnah}}
\hadithdefcmd{abudawud}{3199}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا صَلَّيْتُمْ عَلَى الْمَيِّتِ فَأَخْلِصُوا لَهُ الدُّعَاءَ ‏"‏ ‏.‏\hadithno{3199}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When you pray over the dead, make a sincere supplication for him}}
\hadithdefcmd{abudawud}{3200}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَبُو الْجُلاَسِ، عُقْبَةُ بْنُ سَيَّارٍ حَدَّثَنِي عَلِيُّ بْنُ شَمَّاخٍ، قَالَ شَهِدْتُ مَرْوَانَ سَأَلَ أَبَا هُرَيْرَةَ كَيْفَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى الْجَنَازَةِ قَالَ أَمَعَ الَّذِي قُلْتَ قَالَ نَعَمْ ‏.‏ قَالَ كَلاَمٌ كَانَ بَيْنَهُمَا قَبْلَ ذَلِكَ ‏.‏ قَالَ أَبُو هُرَيْرَةَ ‏ "‏ اللَّهُمَّ أَنْتَ رَبُّهَا وَأَنْتَ خَلَقْتَهَا وَأَنْتَ هَدَيْتَهَا لِلإِسْلاَمِ وَأَنْتَ قَبَضْتَ رُوحَهَا وَأَنْتَ أَعْلَمُ بِسِرِّهَا وَعَلاَنِيَتِهَا جِئْنَاكَ شُفَعَاءَ فَاغْفِرْ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَخْطَأَ شُعْبَةُ فِي اسْمِ عَلِيِّ بْنِ شَمَّاخٍ قَالَ فِيهِ عُثْمَانُ بْنُ شَمَّاسٍ وَسَمِعْتُ أَحْمَدَ بْنَ إِبْرَاهِيمَ الْمَوْصِلِيَّ يُحَدِّثُ أَحْمَدَ بْنَ حَنْبَلٍ قَالَ مَا أَعْلَمُ أَنِّي جَلَسْتُ مِنْ حَمَّادِ بْنِ زَيْدٍ مَجْلِسًا إِلاَّ نَهَى فِيهِ عَنْ عَبْدِ الْوَارِثِ وَجَعْفَرِ بْنِ سُلَيْمَانَ ‏.‏\hadithno{3200}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali ibn Shammakh said:I was present with Marwan who asked AbuHurayrah: Did you hear how the Messenger of Allah (ﷺ) used to pray over the dead? He said: Even with the words that you said. (The narrator said: They exchanged hot words between them before that.) Abu Hurairah said: O Allah, Thou art its Lord. Thou didst create it, Thou didst guide it to Islam, Thou hast taken its spirit, and Thou knowest best its inner nature and outer aspect. We have come as intercessors, so forgive him. Abu Dawud said: Shu'bah made a mistake in mentioning the name of 'Ali b. Shammakh. He said in his version: 'Uthman b. Shammas. Abu Dawud said: I heard Ahmad b. Ibrahim al-Mawsili say that Ahmad b. Hanbal said: In every meeting which I attended with Hammad b. Zaid he forbade to narrate this traditions from 'Abd al-Warith and Ja'far b. Sulaiman}}
\hadithdefcmd{abudawud}{3201}{حَدَّثَنَا مُوسَى بْنُ مَرْوَانَ الرَّقِّيُّ، حَدَّثَنَا شُعَيْبٌ، - يَعْنِي ابْنَ إِسْحَاقَ - عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى جَنَازَةٍ فَقَالَ ‏ "‏ اللَّهُمَّ اغْفِرْ لِحَيِّنَا وَمَيِّتِنَا وَصَغِيرِنَا وَكَبِيرِنَا وَذَكَرِنَا وَأُنْثَانَا وَشَاهِدِنَا وَغَائِبِنَا اللَّهُمَّ مَنْ أَحْيَيْتَهُ مِنَّا فَأَحْيِهِ عَلَى الإِيمَانِ وَمَنْ تَوَفَّيْتَهُ مِنَّا فَتَوَفَّهُ عَلَى الإِسْلاَمِ اللَّهُمَّ لاَ تَحْرِمْنَا أَجْرَهُ وَلاَ تُضِلَّنَا بَعْدَهُ ‏"‏ ‏.‏\hadithno{3201}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: When the Messenger of Allah (ﷺ) prayed over a dead person, he said: O Allah, forgive those of us who are living and those of us who are dead, those of us who are present and those of us who are absent, our young and our old, our male and our female. O Allah, to whomsoever of us Thou givest life grant him life as a believer, and whomsoever of us Thou takest in death take him in death as a follower of Islam. O Allah, do not withhold from us the reward (of faith) and do not lead us astray after his death}}
\hadithdefcmd{abudawud}{3202}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا الْوَلِيدُ، - وَحَدِيثُ عَبْدِ الرَّحْمَنِ أَتَمُّ - حَدَّثَنَا مَرْوَانُ بْنُ جُنَاحٍ، عَنْ يُونُسَ بْنِ مَيْسَرَةَ بْنِ حَلْبَسٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى رَجُلٍ مِنَ الْمُسْلِمِينَ فَسَمِعْتُهُ يَقُولُ ‏"‏ اللَّهُمَّ إِنَّ فُلاَنَ بْنَ فُلاَنٍ فِي ذِمَّتِكَ فَقِهِ فِتْنَةَ الْقَبْرِ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ ‏"‏ فِي ذِمَّتِكَ وَحَبْلِ جِوَارِكَ فَقِهِ مِنْ فِتْنَةِ الْقَبْرِ وَعَذَابِ النَّارِ وَأَنْتَ أَهْلُ الْوَفَاءِ وَالْحَمْدِ اللَّهُمَّ فَاغْفِرْ لَهُ وَارْحَمْهُ إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ عَنْ مَرْوَانَ بْنِ جُنَاحٍ ‏.‏\hadithno{3202}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Wathilah ibn al-Asqa': The Messenger of Allah (ﷺ) led us in prayer over bier of a Muslim and I heard him say: O Allah, so and so, son of so and so, is in Thy protection, so guard him from the trial in the grave. (AbdurRahman in his version said: "In Thy protection and in Thy nearer presence, so guard him from the trial in the grave) and the punishment in Hell. Thou art faithful and worthy of praise. O Allah, forgive him and show him mercy. Thou art the forgiving and the merciful one." AbdurRahman said: "On the authority of Marwan ibn Janah}}
\hadithdefcmd{abudawud}{3203}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ امْرَأَةً، سَوْدَاءَ أَوْ رَجُلاً كَانَ يَقُمُّ الْمَسْجِدَ فَفَقَدَهُ النَّبِيُّ صلى الله عليه وسلم فَسَأَلَ عَنْهُ فَقِيلَ مَاتَ ‏.‏ فَقَالَ ‏"‏ أَلاَّ آذَنْتُمُونِي بِهِ ‏"‏ ‏.‏ قَالَ ‏"‏ دُلُّونِي عَلَى قَبْرِهِ ‏"‏ ‏.‏ فَدَلُّوهُ فَصَلَّى عَلَيْهِ ‏.‏\hadithno{3203}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (458) Sahih Muslim (956)}\hadithtrans{Narrated Abu Hurairah:A negress (or a youth) used to sweep the mosque. The Prophet (ﷺ) missed him, and when he asked about him the people told him that he had died. He said: Why have you not informed me ? He said: Lead me to his grave. So they led him and he prayed over him}}
\hadithdefcmd{abudawud}{3204}{حَدَّثَنَا الْقَعْنَبِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى لِلنَّاسِ النَّجَاشِيَّ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ وَخَرَجَ بِهِمْ إِلَى الْمُصَلَّى فَصَفَّ بِهِمْ وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{3204}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1245) Sahih Muslim (951)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) gave the people news of death of Negus on the day on which he died, took them out to the place of prayer, drew them up in rows and said: "Allah is Most Great" four times}}
\hadithdefcmd{abudawud}{3205}{حَدَّثَنَا عَبَّادُ بْنُ مُوسَى، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَنْطَلِقَ إِلَى أَرْضِ النَّجَاشِيِّ فَذَكَرَ حَدِيثَهُ قَالَ النَّجَاشِيُّ أَشْهَدُ أَنَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَّهُ الَّذِي بَشَّرَ بِهِ عِيسَى ابْنُ مَرْيَمَ وَلَوْلاَ مَا أَنَا فِيهِ مِنَ الْمُلْكِ لأَتَيْتُهُ حَتَّى أَحْمِلَ نَعْلَيْهِ ‏.‏\hadithno{3205}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Burdah:On the authority of his father: The Messenger of Allah (ﷺ) commanded us to proceed to the land of Negus. Mentioning the rest of the tradition he said that Negus said: I bear witness that he is the Messenger of Allah (ﷺ), and it is he about whom Christ son of Mary gave good news. It I were not in the land which I am, I would come to him and carry his shoes}}
\hadithdefcmd{abudawud}{3206}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا سَعِيدُ بْنُ سَالِمٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ الْفَضْلِ السِّجِسْتَانِيُّ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - بِمَعْنَاهُ عَنْ كَثِيرِ بْنِ زَيْدٍ الْمَدَنِيِّ، عَنِ الْمُطَّلِبِ، قَالَ لَمَّا مَاتَ عُثْمَانُ بْنُ مَظْعُونٍ أُخْرِجَ بِجَنَازَتِهِ فَدُفِنَ أَمَرَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً أَنْ يَأْتِيَهُ بِحَجَرٍ فَلَمْ يَسْتَطِعْ حَمْلَهُ فَقَامَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَحَسَرَ عَنْ ذِرَاعَيْهِ - قَالَ كَثِيرٌ قَالَ الْمُطَّلِبُ قَالَ الَّذِي يُخْبِرُنِي ذَلِكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ - كَأَنِّي أَنْظُرُ إِلَى بَيَاضِ ذِرَاعَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ حَسَرَ عَنْهُمَا ثُمَّ حَمَلَهَا فَوَضَعَهَا عِنْدَ رَأْسِهِ وَقَالَ ‏ "‏ أَتَعَلَّمُ بِهَا قَبْرَ أَخِي وَأَدْفِنُ إِلَيْهِ مَنْ مَاتَ مِنْ أَهْلِي ‏"‏ ‏.‏\hadithno{3206}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Muttalib: When Uthman ibn Maz'un died, he was brought out on his bier and buried. The Prophet (ﷺ) ordered a man to bring him a stone, but he was unable to carry it. The Messenger of Allah (ﷺ) got up and going over to it rolled up his sleeves. The narrator Kathir told that al-Muttalib remarked: The one who told me about the Messenger of Allah (ﷺ) said: I still seem to see the whiteness of the forearms of the Messenger of Allah (ﷺ) when he rolled up his sleeves. He then carried it and placed it at his head saying: I am marking my brother's grave with it, and I shall bury beside him those of my family who die}}
\hadithdefcmd{abudawud}{3207}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سَعْدٍ، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَسْرُ عَظْمِ الْمَيِّتِ كَكَسْرِهِ حَيًّا ‏"‏ ‏.‏\hadithno{3207}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: Breaking a dead man's bone is like breaking it when he is alive}}
\hadithdefcmd{abudawud}{3208}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَكَّامُ بْنُ سَلْمٍ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّحْدُ لَنَا وَالشَّقُّ لِغَيْرِنَا ‏"‏ ‏.‏\hadithno{3208}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: The niche in the side of the grave is for us and the excavation in the middle is for others}}
\hadithdefcmd{abudawud}{3209}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ عَامِرٍ، قَالَ غَسَّلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلِيٌّ وَالْفَضْلُ وَأُسَامَةُ بْنُ زَيْدٍ وَهُمْ أَدْخَلُوهُ قَبْرَهُ قَالَ وَحَدَّثَنِي مُرَحَّبٌ أَوِ ابْنُ أَبِي مُرَحَّبٍ أَنَّهُمْ أَدْخَلُوا مَعَهُمْ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ فَلَمَّا فَرَغَ عَلِيٌّ قَالَ إِنَّمَا يَلِي الرَّجُلَ أَهْلُهُ ‏.‏\hadithno{3209}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amir: Ali, Fadl and Usamah ibn Zayd washed the Messenger of Allah (ﷺ) and they put him in his grave. Marhab or Ibn AbuMarhab told me that they also made AbdurRahman ibn Awf join them. When Ali became free, he said: The People of the man serve him}}
\hadithdefcmd{abudawud}{3210}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي مُرَحَّبٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، نَزَلَ فِي قَبْرِ النَّبِيِّ صلى الله عليه وسلم قَالَ كَأَنِّي أَنْظُرُ إِلَيْهِمْ أَرْبَعَةً ‏.‏\hadithno{3210}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Marhab:That 'Abd al-Rahman b. 'Awf alighted in the grave of the Prophet (ﷺ). He said: I still seem to see the four of them}}
\hadithdefcmd{abudawud}{3211}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ أَوْصَى الْحَارِثُ أَنْ يُصَلِّيَ، عَلَيْهِ عَبْدُ اللَّهِ بْنُ يَزِيدَ فَصَلَّى عَلَيْهِ ثُمَّ أَدْخَلَهُ الْقَبْرَ مِنْ قِبَلِ رِجْلَىِ الْقَبْرِ وَقَالَ هَذَا مِنَ السُّنَّةِ ‏.‏\hadithno{3211}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Ishaq said:Al-Harith left his will that Abdullah ibn Yazid should offer his funeral prayer; so he prayed over him. He then put him in the grave from the side of his legs and said: This is a Sunnah (model practice of the Prophet)}}
\hadithdefcmd{abudawud}{3212}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ زَاذَانَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي جَنَازَةِ رَجُلٍ مِنَ الأَنْصَارِ فَانْتَهَيْنَا إِلَى الْقَبْرِ وَلَمْ يُلْحَدْ بَعْدُ فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم مُسْتَقْبِلَ الْقِبْلَةِ وَجَلَسْنَا مَعَهُ ‏.‏\hadithno{3212}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Bara' ibn Azib: We went out with the Messenger of Allah (ﷺ) to the funeral of a man of the Ansar, but when we reached the grave, the niche in the side had not yet been made, so the Prophet (ﷺ) sat down facing the qiblah, and we sat down along with him}}
\hadithdefcmd{abudawud}{3213}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، ح وَحَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الصِّدِّيقِ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا وَضَعَ الْمَيِّتَ فِي الْقَبْرِ قَالَ ‏ "‏ بِسْمِ اللَّهِ وَعَلَى سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏ هَذَا لَفْظُ مُسْلِمٍ ‏.‏\hadithno{3213}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Umar: When the Prophet (ﷺ) placed the dead in the grave, he said: In the name of Allah, and following the Sunnah of the Messenger of Allah (ﷺ). This is Muslim's version}}
\hadithdefcmd{abudawud}{3214}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي أَبُو إِسْحَاقَ، عَنْ نَاجِيَةَ بْنِ كَعْبٍ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ عَمَّكَ الشَّيْخَ الضَّالَّ قَدْ مَاتَ ‏.‏ قَالَ ‏ "‏ اذْهَبْ فَوَارِ أَبَاكَ ثُمَّ لاَ تُحْدِثَنَّ شَيْئًا حَتَّى تَأْتِيَنِي ‏"‏ ‏.‏ فَذَهَبْتُ فَوَارَيْتُهُ وَجِئْتُهُ فَأَمَرَنِي فَاغْتَسَلْتُ وَدَعَا لِي ‏.‏\hadithno{3214}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: I said to the Prophet (ﷺ): Your old and astray uncle has died. He said: Go and bury your father, and then do not do anything until you come to me. So I went, buried him and came to him. He ordered me (to take a bath), so I took a bath, and he prayed for me}}
\hadithdefcmd{abudawud}{3215}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، أَنَّ سُلَيْمَانَ بْنَ الْمُغِيرَةِ، حَدَّثَهُمْ عَنْ حُمَيْدٍ، - يَعْنِي ابْنَ هِلاَلٍ - عَنْ هِشَامِ بْنِ عَامِرٍ، قَالَ جَاءَتِ الأَنْصَارُ إِلَى رَسُولِ اللّ��هِ صلى الله عليه وسلم يَوْمَ أُحُدٍ فَقَالُوا أَصَابَنَا قَرْحٌ وَجَهْدٌ فَكَيْفَ تَأْمُرُنَا قَالَ ‏"‏ احْفِرُوا وَأَوْسِعُوا وَاجْعَلُوا الرَّجُلَيْنِ وَالثَّلاَثَةَ فِي الْقَبْرِ ‏"‏ ‏.‏ قِيلَ فَأَيُّهُمْ يُقَدَّمُ قَالَ ‏"‏ أَكْثَرُهُمْ قُرْآنًا ‏"‏ ‏.‏ قَالَ أُصِيبَ أَبِي يَوْمَئِذٍ عَامِرٌ بَيْنَ اثْنَيْنِ أَوْ قَالَ وَاحِدٌ ‏.‏\hadithno{3215}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hisham ibn Amir: The Ansar came to the Messenger of Allah (ﷺ) on the day of Uhud and said: We have been afflicted with wound and fatigue. What do you command us? He said: Dig graves, make them wide, bury two or three in a single grave. He was asked: Which of them should be put first? He replied: The one who knew the Qur'an most. He (Hisham) said: My father Amir died on the day and was buried with two or one}}
\hadithdefcmd{abudawud}{3216}{حَدَّثَنَا أَبُو صَالِحٍ، - يَعْنِي الأَنْطَاكِيَّ - أَخْبَرَنَا أَبُو إِسْحَاقَ، - يَعْنِي الْفَزَارِيَّ - عَنِ الثَّوْرِيِّ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ فِيهِ ‏ "‏ وَأَعْمِقُوا ‏"‏ ‏.‏\hadithno{3216}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Humaid b. Hilal with a different chain of transmitters and to the same effect. This version adds:"And deepen (the graves)}}
\hadithdefcmd{abudawud}{3217}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرٌ، حَدَّثَنَا حُمَيْدٌ، - يَعْنِي ابْنَ هِلاَلٍ - عَنْ سَعْدِ بْنِ هِشَامِ بْنِ عَامِرٍ، بِهَذَا الْحَدِيثِ ‏.‏\hadithno{3217}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Sa'd b. Hisham b. 'Amir with a different chain of narrators}}
\hadithdefcmd{abudawud}{3218}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي هَيَّاجٍ الأَسَدِيِّ، قَالَ بَعَثَنِي عَلِيٌّ قَالَ لِي أَبْعَثُكَ عَلَى مَا بَعَثَنِي عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ لاَ أَدَعَ قَبْرًا مُشْرِفًا إِلاَّ سَوَّيْتُهُ وَلاَ تِمْثَالاً إِلاَّ طَمَسْتُهُ ‏.‏\hadithno{3218}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (969)}\hadithtrans{Narrated Abu Hayyaj al-Asadi:'Ali said to me: I am sending you on the same mission as the Messenger of Allah (ﷺ) sent me that I should not leave a high grave without leveling it and an image without obliterating it}}
\hadithdefcmd{abudawud}{3219}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا عَلِيٍّ الْهَمْدَانِيَّ، حَدَّثَهُ قَالَ كُنَّا مَعَ فَضَالَةَ بْنِ عُبَيْدٍ بِرُودِسَ مِنْ أَرْضِ الرُّومِ فَتُوُفِّيَ صَاحِبٌ لَنَا فَأَمَرَ فَضَالَةُ بِقَبْرِهِ فَسُوِّيَ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِتَسْوِيَتِهَا ‏.‏ قَالَ أَبُو دَاوُدَ رُودِسُ جَزِيرَةٌ فِي الْبَحْرِ ‏.‏\hadithno{3219}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (969)}\hadithtrans{Narrated Abu 'Ali al-Hamdani: We were with Fudalah b. 'Ubaid at Rudis in the land of Rome. One of our Companions dies, Fudalah commanded us to dig his grave; it was (dug and) levelled. He then said: I heard the Messenger of Allah (ﷺ) commanding to level them. Abu Dawud said: Rudis is an island, in the sea}}
\hadithdefcmd{abudawud}{3220}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ هَانِئٍ، عَنِ الْقَاسِمِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ يَا أُمَّهْ اكْشِفِي لِي عَنْ قَبْرِ النَّبِيِّ صلى الله عليه وسلم وَصَاحِبَيْهِ رضى الله عنهما فَكَشَفَتْ لِي عَنْ ثَلاَثَةِ قُبُورٍ لاَ مُشْرِفَةٍ وَلاَ لاَطِئَةٍ مَبْطُوحَةٍ بِبَطْحَاءِ الْعَرْصَةِ الْحَمْرَاءِ قَالَ أَبُو عَلِيٍّ يُقَالُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مُقَدَّمٌ وَأَبُو بَكْرٍ عِنْدَ رَأْسِهِ وَعُمَرُ عِنْدَ رِجْلَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3220}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Qasim ibn Muhammad ibn AbuBakr: I said to Aisha! Mother, show me the grave of the Messenger of Allah (ﷺ) and his two Companions (Allah be pleased with them). She showed me three graves which were neither high nor low, but were spread with soft red pebbles in an open space. Abu 'Ali said: It is said that the Messenger of Allah (ﷺ) is forward, Abu Bakr is near his head and 'Umar is near is feet. His head is at the feet of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3221}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا هِشَامٌ، عَنْ عَبْدِ اللَّهِ بْنِ بَحِيرٍ، عَنْ هَانِئٍ، مَوْلَى عُثْمَانَ عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا فَرَغَ مِنْ دَفْنِ الْمَيِّتِ وَقَفَ عَلَيْهِ فَقَالَ ‏ "‏ اسْتَغْفِرُوا لأَخِيكُمْ وَسَلُوا لَهُ التَّثْبِيتَ فَإِنَّهُ الآنَ يُسْأَلُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ بَحِيرُ بْنُ رَيْسَانَ ‏.‏\hadithno{3221}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uthman ibn Affan: Whenever the Prophet (ﷺ) became free from burying the dead, he used to stay at him (i.e. his grave) and say: Seek forgiveness for your brother, and beg steadfastness for him, for he will be questioned now. Abu Dawud said: The full name of the narrator Buhair is Buhair b. Raisan}}
\hadithdefcmd{abudawud}{3222}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَقْرَ فِي الإِسْلاَمِ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ كَانُوا يَعْقِرُونَ عِنْدَ الْقَبْرِ بَقَرَةً أَوْ شَاةً ‏.‏\hadithno{3222}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: There is no slaughtering (at the grave) in Islam. 'Abd al-Razzaq said: They used to slaughter cows or sheep at grave}}
\hadithdefcmd{abudawud}{3223}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ ثُمَّ انْصَرَفَ ‏.‏\hadithno{3223}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6426) Sahih Muslim (2296)}\hadithtrans{Narrated 'Uqbah bin 'Amir:One day the Messenger of Allah (ﷺ) went out and prayed over the martyrs of Uhud like his prayer over the dead, and then returned}}
\hadithdefcmd{abudawud}{3224}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، بِهَذَا الْحَدِيثِ قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى عَلَى قَتْلَى أُحُدٍ بَعْدَ ثَمَانِ سِنِينَ كَالْمُوَدِّعِ لِلأَحْيَاءِ وَالأَمْوَاتِ ‏.‏\hadithno{3224}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4042)}\hadithtrans{Narrated Yazid b. Habib:The Prophet (ﷺ) prayed over the martyrs of Uhud after eight years like a man who bids farewell to the living and dead}}
\hadithdefcmd{abudawud}{3225}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُقْعَدَ عَلَى الْقَبْرِ وَأَنْ يُقَصَّصَ وَيُبْنَى عَلَيْهِ ‏.‏\hadithno{3225}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (970)}\hadithtrans{Narrated Jabir:I heard the Prophet (ﷺ) forbid to sit on the grave, to plaster it with gypsum, and to build any structure over it}}
\hadithdefcmd{abudawud}{3226}{حَدَّثَنَا مُسَدَّدٌ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، وَعَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، بِهَذَا الْحَدِيثِ قَالَ أَبُو دَاوُدَ قَالَ عُثْمَانُ أَوْ يُزَادَ عَلَيْهِ وَزَادَ سُلَيْمَانُ بْنُ مُوسَى أَوْ أَنْ يُكْتَبَ عَلَيْهِ وَلَمْ يَذْكُرْ مُسَدَّدٌ فِي حَدِيثِهِ أَوْ يُزَادَ عَلَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ خَفِيَ عَلَىَّ مِنْ حَدِيثِ مُسَدَّدٍ حَرْفُ وَأَنْ ‏.‏\hadithno{3226}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (970)}\hadithtrans{The tradition mentioned above has also been narrated by Jabir through a different chain of transmitters. Abu Dawud said:'Uthman said: "or anything added to it." Sulaiman b. Musa said: "or anything written on it." Musaddad did not mention in his version the words "or anything added to it." Abu Dawud said: The word "and that" (wa an) remained hidden to me}}
\hadithdefcmd{abudawud}{3227}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{3227}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (437) Sahih Muslim (530)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Allah's curse to be on the Jews, they made the graves of their Prophets mosques}}
\hadithdefcmd{abudawud}{3228}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَجْلِسَ أَحَدُكُمْ عَلَى جَمْرَةٍ فَتَحْرِقَ ثِيَابَهُ حَتَّى تَخْلُصَ إِلَى جِلْدِهِ خَيْرٌ لَهُ مِنْ أَنْ يَجْلِسَ عَلَى قَبْرٍ ‏"‏ ‏.‏\hadithno{3228}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (971)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: It is better that one of you should sit on the live coals which burns his clothing and come in contact with his skin than that he should sit on a grave}}
\hadithdefcmd{abudawud}{3229}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ يَزِيدَ بْنِ جَابِرٍ - عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ وَاثِلَةَ بْنَ الأَسْقَعِ، يَقُولُ سَمِعْتُ أَبَا مَرْثَدٍ الْغَنَوِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَجْلِسُوا عَلَى الْقُبُورِ وَلاَ تُصَلُّوا إِلَيْهَا ‏"‏ ‏.‏\hadithno{3229}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (972)}\hadithtrans{Narrated Abu Marthad al-Ghanawi :The Messenger of Allah (ﷺ) as saying: Do not sit on the graves, and do not pray facing them}}
\hadithdefcmd{abudawud}{3230}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا الأَسْوَدُ بْنُ شَيْبَانَ، عَنْ خَالِدِ بْنِ سُمَيْرٍ السَّدُوسِيِّ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ بَشِيرٍ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ اسْمُهُ فِي الْجَاهِلِيَّةِ زَحْمُ بْنُ مَعْبَدٍ فَهَاجَرَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا اسْمُكَ ‏"‏ ‏.‏ قَالَ زَحْمٌ ‏.‏ قَالَ ‏"‏ بَلْ أَنْتَ بَشِيرٌ ‏"‏ ‏.‏ قَالَ بَيْنَمَا أَنَا أُمَاشِي رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِقُبُورِ الْمُشْرِكِينَ فَقَالَ ‏"‏ لَقَدْ سَبَقَ هَؤُلاَءِ خَيْرًا كَثِيرًا ‏"‏ ‏.‏ ثَلاَثًا ثُمَّ مَرَّ بِقُبُورِ الْمُسْلِمِينَ فَقَالَ ‏"‏ لَقَدْ أَدْرَكَ هَؤُلاَءِ خَيْرًا كَثِيرًا ‏"‏ ‏.‏ وَحَانَتْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم نَظْرَةٌ فَإِذَا رَجُلٌ يَمْشِي فِي الْقُبُورِ عَلَيْهِ نَعْلاَنِ فَقَالَ ‏"‏ يَا صَاحِبَ السِّبْتِيَّتَيْنِ وَيْحَكَ أَلْقِ سِبْتِيَّتَيْكَ ‏"‏ ‏.‏ فَنَظَرَ الرَّجُلُ فَلَمَّا عَرَفَ رَسُولَ اللَّهِ صلى الله عليه وسلم خَلَعَهُمَا فَرَمَى بِهِمَا ‏.‏\hadithno{3230}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Bashir, the Client of the Messenger of Allah: Bashir's name in pre-Islamic days was Zahm ibn Ma'bad. When he migrated to the Messenger of Allah (ﷺ). He asked: What is your name? He replied: Zahm. He said: No, you are Bashir. He (Bashir) said: When I was walking with the Messenger of Allah (ﷺ) he passed by the graves of the polytheists. He said: They lived before (a period of) abundant good. He said this three times. He then passed by the graves of Muslims. He said: They received abundant good. The Messenger of Allah (ﷺ) suddenly saw a man walking in shoes between the graves. He said: O man, wearing the shoes! Woe to thee! Take off thy shoes. So the man looked (round), When he recognized the Messenger of Allah (ﷺ), he took them off and threw them away}}
\hadithdefcmd{abudawud}{3231}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَطَاءٍ - عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ الْعَبْدَ إِذَا وُضِعَ فِي قَبْرِهِ وَتَوَلَّى عَنْهُ أَصْحَابُهُ إِنَّهُ لَيَسْمَعُ قَرْعَ نِعَالِهِمْ ‏"‏ ‏.‏\hadithno{3231}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1338) Sahih Muslim (2870)}\hadithtrans{Narrated Anas:The Prophet (ﷺ) as saying: When a servant (of Allah) is placed in his grave, and his Companions depart from him, he hears the stepping sound of their shoes}}
\hadithdefcmd{abudawud}{3232}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سَعِيدِ بْنِ يَزِيدَ أَبِي مَسْلَمَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ جَابِرٍ، قَالَ دُفِنَ مَعَ أَبِي رَجُلٌ فَكَانَ فِي نَفْسِي مِنْ ذَلِكَ حَاجَةٌ فَأَخْرَجْتُهُ بَعْدَ سِتَّةِ أَشْهُرٍ فَمَا أَنْكَرْتُ مِنْهُ شَيْئًا إِلاَّ شُعَيْرَاتٍ كُنَّ فِي لِحْيَتِهِ مِمَّا يَلِي الأَرْضَ ‏.‏\hadithno{3232}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir:A man was buried with my father. I had a desire at heart for that (place for my burial). So I took him out after six months. I did not find any change (in his body) except a few hair that touched the earth}}
\hadithdefcmd{abudawud}{3233}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ عَامِرٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَرُّوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِجَنَازَةٍ فَأَثْنَوْا عَلَيْهَا خَيْرًا فَقَالَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ ثُمَّ مَرُّوا بِأُخْرَى فَأَثْنَوْا عَلَيْهَا شَرًّا فَقَالَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ بَعْضَكُمْ عَلَى بَعْضٍ شُهَدَاءُ ‏"‏ ‏.‏\hadithno{3233}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: People with a bier passed by the Messenger of Allah (ﷺ). They (the companions) spoke highly of him. He said: Paradise is certain for him. Then some people with another (bier) passed by him. They spoke very badly of him. He said: Hell is certain for him. He then said: Some of you are witness to others}}
\hadithdefcmd{abudawud}{3234}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْرَ أُمِّهِ فَبَكَى وَأَبْكَى مَنْ حَوْلَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْتَأْذَنْتُ رَبِّي تَعَالَى عَلَى أَنْ أَسْتَغْفِرَ لَهَا فَلَمْ يُؤْذَنْ لِي فَاسْتَأْذَنْتُ أَنْ أَزُورَ قَبْرَهَا فَأُذِنَ لِي فَزُورُوا الْقُبُورَ فَإِنَّهَا تُذَكِّرُ بِالْمَوْتِ ‏"‏ ‏.‏\hadithno{3234}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (976)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) visited his mother's grave and wept and cause those around him to weep. The Messenger of Allah (ﷺ) then said: I asked my Lord's permission to pray for forgiveness for her, but I was not allowed. I then asked His permission to visit her grave, and I was allowed. So visit graves, for they make one mindful of death}}
\hadithdefcmd{abudawud}{3235}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا مُعَرِّفُ بْنُ وَاصِلٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا فَإِنَّ فِي زِيَارَتِهَا تَذْكِرَةً ‏"‏ ‏.‏\hadithno{3235}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (977)}\hadithtrans{Narrated Buraidah:The Messenger of Allah (ﷺ) as saying: I forbade you to visit graves, but you may now visit them, for in visiting them there is a reminder (of death)}}
\hadithdefcmd{abudawud}{3236}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَائِرَاتِ الْقُبُورِ وَالْمُتَّخِذِينَ عَلَيْهَا الْمَسَاجِدَ وَالسُّرُجَ ‏.‏\hadithno{3236}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) cursed women who visit graves, those who built mosques over them and erected lamps (there)}}
\hadithdefcmd{abudawud}{3237}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمَقْبَرَةِ فَقَالَ ‏ "‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ ‏"‏ ‏.‏ ‏.‏\hadithno{3237}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (249)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) went out to the graveyard and said: Peace be upon you, inhabitants of the dwellings who are of the community of the believers. If Allah wills we shall join you}}
\hadithdefcmd{abudawud}{3238}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِرَجُلٍ وَقَصَتْهُ رَاحِلَتُهُ فَمَاتَ وَهُوَ مُحْرِمٌ فَقَالَ ‏"‏ كَفِّنُوهُ فِي ثَوْبَيْهِ وَاغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ يُلَبِّي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ فِي هَذَا الْحَدِيثِ خَمْسُ سُنَنٍ ‏"‏ كَفِّنُوهُ فِي ثَوْبَيْهِ ‏"‏ ‏.‏ أَىْ يُكَفَّنُ الْمَيِّتُ فِي ثَوْبَيْنِ ‏"‏ وَاغْسِلُوهُ بِمَاءٍ وَسِدْرٍ ‏"‏ ‏.‏ أَىْ إِنَّ فِي الْغَسَلاَتِ كُلِّهَا سِدْرًا ‏"‏ وَلاَ تُخَمِّرُوا رَأْسَهُ ‏"‏ ‏.‏ وَلاَ تُقَرِّبُوهُ طِيبًا وَكَانَ الْكَفَنُ مِنْ جَمِيعِ الْمَالِ ‏.‏\hadithno{3238}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1267) Sahih Muslim (1206)}\hadithtrans{Narrated Ibn 'Abbas: To the Messenger of Allah (ﷺ) was brought man wearing ihram who was thrown by his she-camel and has his neck broken and had died. He then said: Shroud him in his two garments, was him with water and lotus leaves, but do not cover his head, for he will be raised on the Day of Resurrection saying the talbiyah. Abu Dawud said: I heard Ahmad b. Hanbal say: There are five rules of the law (sunan) in this tradition: "Shroud him in his two garment," that is, the dead should be shrouded in his two garments. "Wash him with water and lotus leaves," that is, washing all times should be with lotus leaves. Do not bring any perfume near him. The shroud will be made from the property (of the dead)}}
\hadithdefcmd{abudawud}{3239}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عُبَيْدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، وَأَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، نَحْوَهُ قَالَ ‏"‏ وَكَفِّنُوهُ فِي ثَوْبَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ سُلَيْمَانُ قَالَ أَيُّوبُ ‏"‏ ثَوْبَيْهِ ‏"‏ ‏.‏ وَقَالَ عَمْرٌو ‏"‏ ثَوْبَيْنِ ‏"‏ ‏.‏ وَقَالَ ابْنُ عُبَيْدٍ قَالَ أَيُّوبُ ‏"‏ فِي ثَوْبَيْنِ ‏"‏ ‏.‏ وَقَالَ عَمْرٌو ‏"‏ فِي ثَوْبَيْهِ ‏"‏ ‏.‏ زَادَ سُلَيْمَانُ وَحْدَهُ ‏"‏ وَلاَ تُحَنِّطُوهُ ‏"‏ ‏.‏\hadithno{3239}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1849) Sahih Muslim (1206)}\hadithtrans{A similar tradition has also been narrated by Ibn 'Abbas through a different chain of narrators. This version has:"Shroud him in two garments." Abu Dawud said: The narrator Sulaiman said the Ayyub said: "his two garments," 'Amr said: "tow garments," Ibn 'Ubaid said that Ayyub said: "in two garments" and Amr said: "in his two garments." Sulaiman alone added: "do not put any perfume on him}}
\hadithdefcmd{abudawud}{3240}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، نَحْوَهُ بِمَعْنَى سُلَيْمَانَ ‏ "‏ فِي ثَوْبَيْنِ ‏"‏ ‏.‏\hadithno{3240}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{A similar tradition has also been narrated by Ibn 'Abbas through a different chain of transmitters to the effect as narrated by Sulaiman saying:"in two garments}}
\hadithdefcmd{abudawud}{3241}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَقَصَتْ بِرَجُلٍ مُحْرِمٍ نَاقَتُهُ فَقَتَلَتْهُ فَأُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْسِلُوهُ وَكَفِّنُوهُ وَلاَ تُغَطُّوا رَأْسَهُ وَلاَ تُقَرِّبُوهُ طِيبًا فَإِنَّهُ يُبْعَثُ يُهِلُّ ‏"‏ ‏.‏\hadithno{3241}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1839)}\hadithtrans{Narrated Ibn 'Abbas:A man wearing ihram was thrown by his she-camel and had his neck broken and he died. He was brought to the Messenger of Allah (ﷺ), and he said: Wash and shroud him, but do not cover his head and do not put any perfume on him, for he will be raised on the Day of Resurrection saying the talbiyah}}
